@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2015-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2015-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, aCaB, Mickey Sola
@@ -161,12 +161,12 @@ int onas_check_remote(struct onas_context **ctx, cl_error_t *err)
 }
 
 /* pings clamd at the specified interval the number of time specified
- * return 0 on a succesful connection, 1 upon timeout, -1 on error */
+ * return 0 on a successful connection, 1 upon timeout, -1 on error */
 int16_t onas_ping_clamd(struct onas_context **ctx)
 {
 
-    uint64_t attempts           = 0;
-    uint64_t interval           = 0;
+    uint64_t attempts           = ONAS_DEFAULT_PING_ATTEMPTS;
+    uint64_t interval           = ONAS_DEFAULT_PING_INTERVAL;
     char *attempt_str           = NULL;
     char *interval_str          = NULL;
     char *errchk                = NULL;
@@ -207,8 +207,8 @@ int16_t onas_ping_clamd(struct onas_context **ctx)
     /* ping command takes the form --ping [attempts[:interval]] */
     opt = optget((*ctx)->opts, "ping");
 
-    if (opt) {
-        attempt_str = cli_strdup(opt->strarg);
+    if (opt->enabled) {
+        attempt_str = cli_safer_strdup(opt->strarg);
         if (attempt_str) {
             if (NULL == attempt_str) {
                 logg(LOGG_ERROR, "could not allocate memory for string\n");
@@ -225,8 +225,6 @@ int16_t onas_ping_clamd(struct onas_context **ctx)
                     ret = -1;
                     goto done;
                 }
-            } else {
-                interval = ONAS_DEFAULT_PING_INTERVAL;
             }
             attempts = cli_strntoul(attempt_str, strlen(attempt_str), &errchk, 10);
             if (attempt_str + strlen(attempt_str) > errchk) {
@@ -234,9 +232,6 @@ int16_t onas_ping_clamd(struct onas_context **ctx)
                 ret = -1;
                 goto done;
             }
-        } else {
-            attempts = ONAS_DEFAULT_PING_ATTEMPTS;
-            interval = ONAS_DEFAULT_PING_INTERVAL;
         }
     }
 
@@ -406,7 +401,6 @@ cl_error_t onas_setup_client(struct onas_context **ctx)
 {
 
     const struct optstruct *opts;
-    const struct optstruct *opt;
     cl_error_t err;
     int remote;
 
@@ -531,7 +525,7 @@ int onas_get_clamd_version(struct onas_context **ctx)
  * @param fd        the file descriptor for the file to be scanned, often (but not always) this is held by fanotify
  * @param timeout   time in ms to allow curl before timing out connection attempts
  * @param sb        variable to store and pass all of our stat info on the file so we don't have to access it multiple times (triggering multiple events)
- * @param infected  return variable indincating whether daemon returned with an infected verdict or not
+ * @param infected  return variable indicating whether daemon returned with an infected verdict or not
  * @param err       return variable passed to the daemon protocol interface indicating how many things went wrong in the course of scanning
  * @param ret_code  return variable passed to the daemon protocol interface indicating last known issue or success
  */
