@@ -1,7 +1,7 @@
 /*
  *  Load, verify and execute ClamAV bytecode.
  *
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2009-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -199,9 +199,7 @@ struct cli_bc_ctx {
     unsigned found;
     unsigned ninflates;
     unsigned nlzmas;
-#if HAVE_BZLIB_H
     unsigned nbzip2s;
-#endif
     bc_dbg_callback_trace trace;
     bc_dbg_callback_trace_op trace_op;
     bc_dbg_callback_trace_val trace_val;
@@ -216,9 +214,7 @@ struct cli_bc_ctx {
     mpool_t *mpool;
     struct bc_inflate *inflates;
     struct bc_lzma *lzmas;
-#if HAVE_BZLIB_H
     struct bc_bzip2 *bzip2s;
-#endif
     struct bc_buffer *buffers;
     unsigned nbuffers;
     unsigned nhashsets;
@@ -236,10 +232,8 @@ struct cli_bc_ctx {
     cli_events_t *bc_events;
     int on_jit;
     int no_diff;
-#if HAVE_JSON
     void **jsonobjs;
     unsigned njsonobjs;
-#endif
 };
 struct cli_all_bc;
 cl_error_t cli_vm_execute(const struct cli_bc *bc, struct cli_bc_ctx *ctx, const struct cli_bc_func *func, const struct cli_bc_inst *inst);
