@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2010-2013 Sourcefire, Inc.
  *
  *  Authors: aCaB <acab@clamav.net>, Török Edvin <edwin@clamav.net>
@@ -31,263 +31,28 @@
 #include "mpool.h"
 #include "clamav.h"
 #include "cache.h"
+#include "math.h"
 #include "fmap.h"
 
-// #define USE_LRUHASHCACHE /* The replacement policy algorithm to use */
-#define USE_SPLAY
+#include "clamav_rust.h"
 
-#if defined(CL_THREAD_SAFE) && defined(USE_LRUHASHCACHE)
-static pthread_mutex_t pool_mutex = PTHREAD_MUTEX_INITIALIZER;
-#endif
-
-/* The number of root trees and the chooser function
+/* The chooser function
    Each tree is protected by a mutex against concurrent access */
-/* #define TREES 1 */
-/* static inline unsigned int getkey(uint8_t *hash) { return 0; } */
-#define TREES 256
-static inline unsigned int getkey(uint8_t *hash)
+static inline unsigned int getkey(uint8_t *hash, size_t trees)
 {
-    return *hash;
-}
-/* #define TREES 4096 */
-/* static inline unsigned int getkey(uint8_t *hash) { return hash[0] | ((unsigned int)(hash[1] & 0xf)<<8) ; } */
-/* #define TREES 65536 */
-/* static inline unsigned int getkey(uint8_t *hash) { return hash[0] | (((unsigned int)hash[1])<<8) ; } */
-
-/* The number of nodes in each tree */
-#define NODES 256
-
-/* LRUHASHCACHE --------------------------------------------------------------------- */
-#ifdef USE_LRUHASHCACHE
-struct cache_key {
-    int64_t digest[2];
-    uint32_t size; /* 0 is used to mark an empty hash slot! */
-    struct cache_key *lru_next, *lru_prev;
-};
-
-struct cache_set {
-    struct cache_key *data;
-    size_t maxelements; /* considering load factor */
-    size_t maxdeleted;
-    size_t elements;
-    size_t deleted;
-    struct cache_key *lru_head, *lru_tail;
-};
-
-#define CACHE_KEY_DELETED ~0u
-#define CACHE_KEY_EMPTY 0
-
-static void cacheset_lru_remove(struct cache_set *map, size_t howmany)
-{
-    while (howmany--) {
-        struct cache_key *old;
-        assert(map->lru_head);
-        /* Remove a key from the head of the list */
-        old = map->lru_head;
-        assert(!old->lru_prev);
-        map->lru_head = old->lru_next;
-        old->size     = CACHE_KEY_DELETED;
-        /* This slot is now deleted, it is not empty,
-	 * because previously we could have inserted a key that has seen this
-	 * slot as occupied, to find that key we need to ensure that all keys
-	 * that were occupied when the key was inserted, are seen as occupied
-	 * when searching too.
-	 * Of course when inserting a new value, we treat deleted slots as
-	 * empty.
-	 * We only replace old values with new values, but there is no guarantee
-	 * that the newly inserted value would hash to same place as the value
-	 * we remove due to LRU! */
-        if (old == map->lru_tail)
-            map->lru_tail = 0;
-        map->elements--;
-        map->deleted++;
+    if (hash) {
+        // Take the first two bytes (16 bits) of the hash, which total to 65536 values,
+        // and modulus that by the number of trees desired.
+        // As long as trees < 65536, and the hash is uniformly distributed,
+        // the resulting key will be a good value to use a bucket identifier
+        // for evenly placing values.
+        return (hash[0] | (((unsigned int)hash[1]) << 8)) % trees;
     }
-}
 
-static inline int cacheset_lookup_internal(struct cache_set *map,
-                                           const char *md5, size_t size,
-                                           uint32_t *insert_pos, int deletedok)
-{
-    const struct cache_key *data = map->data;
-    uint32_t capmask             = NODES - 1;
-    const struct cache_key *k;
-    uint32_t idx, tries = 0;
-    uint64_t md5_0, md5_1;
-    uint64_t md5a[2];
-
-    memcpy(&md5a, md5, 16);
-    md5_0 = md5a[0];
-    md5_1 = md5a[1];
-    idx   = md5_1 & capmask;
-    k     = &data[idx];
-    while (k->size != CACHE_KEY_EMPTY && tries <= capmask) {
-        if (k->digest[0] == md5_0 &&
-            k->digest[1] == md5_1 &&
-            k->size == size) {
-            /* found key */
-            *insert_pos = idx;
-            return 1;
-        }
-        if (deletedok && k->size == CACHE_KEY_DELETED) {
-            /* treat deleted slot as empty */
-            *insert_pos = idx;
-            return 0;
-        }
-        idx = (idx + tries++) & capmask;
-        k   = &data[idx];
-    }
-    /* found empty pos */
-    *insert_pos = idx;
     return 0;
 }
 
-static inline void lru_remove(struct cache_set *map, struct cache_key *newkey)
-{
-    if (newkey->lru_next)
-        newkey->lru_next->lru_prev = newkey->lru_prev;
-    if (newkey->lru_prev)
-        newkey->lru_prev->lru_next = newkey->lru_next;
-    if (newkey == map->lru_head)
-        map->lru_head = newkey->lru_next;
-}
-
-static inline void lru_addtail(struct cache_set *map, struct cache_key *newkey)
-{
-    if (!map->lru_head)
-        map->lru_head = newkey;
-    if (map->lru_tail)
-        map->lru_tail->lru_next = newkey;
-    newkey->lru_next = NULL;
-    newkey->lru_prev = map->lru_tail;
-    map->lru_tail    = newkey;
-}
-
-static void cacheset_add(struct cache_set *map, unsigned char *md5, size_t size, mpool_t *mempool);
-static int cacheset_init(struct cache_set *map, mpool_t *mempool);
-
-static void cacheset_rehash(struct cache_set *map, mpool_t *mempool)
-{
-    unsigned i;
-    int ret;
-    struct cache_set tmp_set;
-    struct cache_key *key;
-#ifdef CL_THREAD_SAFE
-    pthread_mutex_lock(&pool_mutex);
-#endif
-    ret = cacheset_init(&tmp_set, mempool);
-#ifdef CL_THREAD_SAFE
-    pthread_mutex_unlock(&pool_mutex);
-#endif
-    if (ret)
-        return;
-
-    key = map->lru_head;
-    for (i = 0; key && i < tmp_set.maxelements / 2; i++) {
-        cacheset_add(&tmp_set, (unsigned char *)&key->digest, key->size, mempool);
-        key = key->lru_next;
-    }
-#ifdef CL_THREAD_SAFE
-    pthread_mutex_lock(&pool_mutex);
-#endif
-    MPOOL_FREE(mempool, map->data);
-#ifdef CL_THREAD_SAFE
-    pthread_mutex_unlock(&pool_mutex);
-#endif
-    memcpy(map, &tmp_set, sizeof(tmp_set));
-}
-
-static void cacheset_add(struct cache_set *map, unsigned char *md5, size_t size, mpool_t *mempool)
-{
-    int ret;
-    uint32_t pos;
-    struct cache_key *newkey;
-
-    if (map->elements >= map->maxelements) {
-        cacheset_lru_remove(map, 1);
-        if (map->deleted >= map->maxdeleted) {
-            cacheset_rehash(map, mempool);
-        }
-    }
-    assert(map->elements < map->maxelements);
-
-    ret    = cacheset_lookup_internal(map, md5, size, &pos, 1);
-    newkey = &map->data[pos];
-    if (newkey->size == CACHE_KEY_DELETED)
-        map->deleted--;
-    if (ret) {
-        /* was already added, remove from LRU list */
-        lru_remove(map, newkey);
-    }
-    /* add new key to tail of LRU list */
-    memcpy(&map->data[pos].digest, md5, sizeof(map->data[pos].digest));
-    map->data[pos].size = size;
-    lru_addtail(map, newkey);
-
-    map->elements++;
-
-    assert(pos < map->maxelements);
-}
-
-static void cacheset_remove(struct cache_set *map, unsigned char *md5, size_t size, mpool_t *mempool)
-{
-    int ret;
-    uint32_t pos;
-    struct cache_key *newkey;
-    ret    = cacheset_lookup_internal(map, md5, size, &pos, 1);
-    newkey = &map->data[pos];
-    if (!ret || (newkey->size == CACHE_KEY_DELETED)) {
-        /* already deleted */
-        return;
-    }
-    /* remove from list */
-    lru_remove(map, newkey);
-    newkey->size = CACHE_KEY_DELETED;
-    map->deleted++;
-    map->elements--;
-    if (map->deleted >= map->maxdeleted) {
-        cacheset_rehash(map, mempool);
-    }
-}
-
-static int cacheset_lookup(struct cache_set *map, unsigned char *md5, size_t size)
-{
-    struct cache_key *newkey;
-    int ret;
-    uint32_t pos;
-
-    ret = cacheset_lookup_internal(map, md5, size, &pos, 0);
-    if (!ret)
-        return 0;
-    newkey = &map->data[pos];
-    /* update LRU position: move to tail */
-    lru_remove(map, newkey);
-    lru_addtail(map, newkey);
-    return 1;
-}
-
-static int cacheset_init(struct cache_set *map, mpool_t *mempool)
-{
-    map->data = MPOOL_CALLOC(mempool, NODES, sizeof(*map->data));
-    if (!map->data)
-        return CL_EMEM;
-    map->maxelements = 80 * NODES / 100;
-    map->maxdeleted  = NODES - map->maxelements - 1;
-    map->elements    = 0;
-    map->lru_head = map->lru_tail = NULL;
-    return 0;
-}
-
-static inline void cacheset_destroy(struct cache_set *cs, mpool_t *mempool)
-{
-    MPOOL_FREE(mempool, cs->data);
-    cs->data = NULL;
-}
-
-#endif /* USE_LRUHASHCACHE */
-
 /* SPLAY --------------------------------------------------------------------- */
-#ifdef USE_SPLAY
-
 struct node { /* a node */
     int64_t digest[2];
     struct node *left;
@@ -306,8 +71,17 @@ struct cache_set { /* a tree */
     struct node *last;
 };
 
+struct CACHE {
+    struct cache_set cacheset;
+    uint32_t trees;
+    uint32_t nodes_per_tree;
+#ifdef CL_THREAD_SAFE
+    pthread_mutex_t mutex;
+#endif
+};
+
 /* Allocates all the nodes and sets up the replacement chain */
-static int cacheset_init(struct cache_set *cs, mpool_t *mempool)
+static int cacheset_init(struct cache_set *cs, mpool_t *mempool, uint32_t nodes_per_tree)
 {
     unsigned int i;
 
@@ -315,19 +89,19 @@ static int cacheset_init(struct cache_set *cs, mpool_t *mempool)
     UNUSEDPARAM(mempool);
 #endif
 
-    cs->data = MPOOL_CALLOC(mempool, NODES, sizeof(*cs->data));
+    cs->data = MPOOL_CALLOC(mempool, nodes_per_tree, sizeof(*cs->data));
     cs->root = NULL;
 
     if (!cs->data)
         return 1;
 
-    for (i = 1; i < NODES; i++) {
+    for (i = 1; i < nodes_per_tree; i++) {
         cs->data[i - 1].next = &cs->data[i];
         cs->data[i].prev     = &cs->data[i - 1];
     }
 
     cs->first = cs->data;
-    cs->last  = &cs->data[NODES - 1];
+    cs->last  = &cs->data[nodes_per_tree - 1];
 
     return 0;
 }
@@ -343,7 +117,7 @@ static inline void cacheset_destroy(struct cache_set *cs, mpool_t *mempool)
     cs->data = NULL;
 }
 
-/* The left/right cooser for the splay tree */
+/* The left/right chooser for the splay tree */
 static inline int cmp(int64_t *a, ssize_t sa, int64_t *b, ssize_t sb)
 {
     if (a[1] < b[1]) return -1;
@@ -487,7 +261,7 @@ static inline void printchain(const char *prefix, struct cache_set *cs)
     }
 }
 #else
-#define printchain(a, b) (0)
+#define printchain(a, b)
 #endif
 
 /* Looks up a node and splays it up to the root of the tree */
@@ -593,7 +367,7 @@ static inline int cacheset_lookup(struct cache_set *cs, unsigned char *md5, size
 /* If the hash is present nothing happens.
    Otherwise a new node is created for the hash picking one from the begin of the chain.
    Used nodes are moved to the end of the chain */
-static inline void cacheset_add(struct cache_set *cs, unsigned char *md5, size_t size, uint32_t recursion_level)
+static inline const char *cacheset_add(struct cache_set *cs, unsigned char *md5, size_t size, uint32_t recursion_level)
 {
     struct node *newnode;
     int64_t hash[2];
@@ -602,13 +376,12 @@ static inline void cacheset_add(struct cache_set *cs, unsigned char *md5, size_t
     if (splay(hash, size, cs)) {
         if (cs->root->minrec > recursion_level)
             cs->root->minrec = recursion_level;
-        return; /* Already there */
+        return NULL; /* Already there */
     }
 
     ptree("1:\n");
     if (printtree(cs, cs->root, 0)) {
-        cli_errmsg("cacheset_add: inconsistent tree before choosing newnode, good luck\n");
-        return;
+        return "cacheset_add: inconsistent tree before choosing newnode, good luck";
     }
 
     newnode = cs->first;
@@ -617,18 +390,15 @@ static inline void cacheset_add(struct cache_set *cs, unsigned char *md5, size_t
             break;
         if (newnode->next) {
             if (newnode == newnode->next) {
-                cli_errmsg("cacheset_add: cache chain in a bad state\n");
-                return;
+                return "cacheset_add: cache chain in a bad state";
             }
             newnode = newnode->next;
         } else {
-            cli_warnmsg("cacheset_add: end of chain reached\n");
-            return;
+            return "cacheset_add: end of chain reached";
         }
     }
     if (!newnode) {
-        cli_errmsg("cacheset_add: tree has got no end nodes\n");
-        return;
+        return "cacheset_add: tree has got no end nodes";
     }
     if (newnode->up) {
         if (newnode->up->left == newnode)
@@ -650,8 +420,7 @@ static inline void cacheset_add(struct cache_set *cs, unsigned char *md5, size_t
 
     ptree("2:\n");
     if (printtree(cs, cs->root, 0)) {
-        cli_errmsg("cacheset_add: inconsistent tree before adding newnode, good luck\n");
-        return;
+        return "cacheset_add: inconsistent tree before adding newnode, good luck";
     }
 
     if (!cs->root) {
@@ -679,10 +448,10 @@ static inline void cacheset_add(struct cache_set *cs, unsigned char *md5, size_t
 
     ptree("3: %lld\n", hash[1]);
     if (printtree(cs, cs->root, 0)) {
-        cli_errmsg("cacheset_add: inconsistent tree after adding newnode, good luck\n");
-        return;
+        return "cacheset_add: inconsistent tree after adding newnode, good luck";
     }
     printnode("newnode", cs, newnode);
+    return NULL;
 }
 
 /* If the hash is not present nothing happens other than splaying the tree.
@@ -756,49 +525,82 @@ static inline void cacheset_remove(struct cache_set *cs, unsigned char *md5, siz
 
     printchain("remove (after)", cs);
 }
-#endif /* USE_SPLAY */
 
-/* COMMON STUFF --------------------------------------------------------------------- */
+/* Looks up an hash in the proper tree */
+static int cache_lookup_hash(unsigned char *md5, size_t len, struct CACHE *cache, uint32_t recursion_level)
+{
+    unsigned int key = 0;
+    int ret          = CL_VIRUS;
+    struct CACHE *c;
+
+    if (!md5) {
+        cli_dbgmsg("cache_lookup: No hash available. Nothing to look up.\n");
+        return ret;
+    }
+
+    key = getkey(md5, cache->trees);
+
+    c = &cache[key];
 
-struct CACHE {
-    struct cache_set cacheset;
 #ifdef CL_THREAD_SAFE
-    pthread_mutex_t mutex;
+    if (pthread_mutex_lock(&c->mutex)) {
+        cli_errmsg("cache_lookup_hash: cache_lookup_hash: mutex lock fail\n");
+        return ret;
+    }
 #endif
-};
 
-/* Allocates the trees for the engine cache */
-int cli_cache_init(struct cl_engine *engine)
+    ret = (cacheset_lookup(&c->cacheset, md5, len, recursion_level)) ? CL_CLEAN : CL_VIRUS;
+
+#ifdef CL_THREAD_SAFE
+    pthread_mutex_unlock(&c->mutex);
+#endif
+
+    return ret;
+}
+
+int clean_cache_init(struct cl_engine *engine)
 {
     struct CACHE *cache;
     unsigned int i, j;
 
     if (!engine) {
-        cli_errmsg("cli_cache_init: mpool malloc fail\n");
+        cli_errmsg("clean_cache_init: mpool malloc fail\n");
         return 1;
     }
 
     if (engine->engine_options & ENGINE_OPTIONS_DISABLE_CACHE) {
-        cli_dbgmsg("cli_cache_init: Caching disabled.\n");
+        cli_dbgmsg("clean_cache_init: Caching disabled.\n");
         return 0;
     }
 
-    if (!(cache = MPOOL_MALLOC(engine->mempool, sizeof(struct CACHE) * TREES))) {
-        cli_errmsg("cli_cache_init: mpool malloc fail\n");
+    // The user requested the cache size to be engine->cache_size
+    // The nodes within each tree are locked together, so having one tree would result in excessive lock contention.
+    // However, having too many trees is inefficient.
+    // A good balance is to have trees and nodes per tree be equal, which is done by using the sqrt of the user request cache size.
+    const uint32_t trees          = ceil(sqrt(engine->cache_size));
+    const uint32_t nodes_per_tree = ceil(sqrt(engine->cache_size));
+
+    cli_dbgmsg("clean_cache_init: Requested cache size: %d. Actual cache size: %d. Trees: %d. Nodes per tree: %d.\n", engine->cache_size, trees * nodes_per_tree, trees, nodes_per_tree);
+
+    if (!(cache = MPOOL_MALLOC(engine->mempool, sizeof(struct CACHE) * trees))) {
+        cli_errmsg("clean_cache_init: mpool malloc fail\n");
         return 1;
     }
 
-    for (i = 0; i < TREES; i++) {
+    cache->trees          = trees;
+    cache->nodes_per_tree = nodes_per_tree;
+
+    for (i = 0; i < trees; i++) {
 #ifdef CL_THREAD_SAFE
         if (pthread_mutex_init(&cache[i].mutex, NULL)) {
-            cli_errmsg("cli_cache_init: mutex init fail\n");
+            cli_errmsg("clean_cache_init: mutex init fail\n");
             for (j = 0; j < i; j++) cacheset_destroy(&cache[j].cacheset, engine->mempool);
             for (j = 0; j < i; j++) pthread_mutex_destroy(&cache[j].mutex);
             MPOOL_FREE(engine->mempool, cache);
             return 1;
         }
 #endif
-        if (cacheset_init(&cache[i].cacheset, engine->mempool)) {
+        if (cacheset_init(&cache[i].cacheset, engine->mempool, cache->nodes_per_tree)) {
             for (j = 0; j < i; j++) cacheset_destroy(&cache[j].cacheset, engine->mempool);
 #ifdef CL_THREAD_SAFE
             for (j = 0; j <= i; j++) pthread_mutex_destroy(&cache[j].mutex);
@@ -811,8 +613,7 @@ int cli_cache_init(struct cl_engine *engine)
     return 0;
 }
 
-/* Frees the engine cache */
-void cli_cache_destroy(struct cl_engine *engine)
+void clean_cache_destroy(struct cl_engine *engine)
 {
     struct CACHE *cache;
     unsigned int i;
@@ -824,7 +625,7 @@ void cli_cache_destroy(struct cl_engine *engine)
         return;
     }
 
-    for (i = 0; i < TREES; i++) {
+    for (i = 0; i < cache->trees; i++) {
         cacheset_destroy(&cache[i].cacheset, engine->mempool);
 #ifdef CL_THREAD_SAFE
         pthread_mutex_destroy(&cache[i].mutex);
@@ -833,35 +634,11 @@ void cli_cache_destroy(struct cl_engine *engine)
     MPOOL_FREE(engine->mempool, cache);
 }
 
-/* Looks up an hash in the proper tree */
-static int cache_lookup_hash(unsigned char *md5, size_t len, struct CACHE *cache, uint32_t recursion_level)
+void clean_cache_add(unsigned char *md5, size_t size, cli_ctx *ctx)
 {
-    unsigned int key = getkey(md5);
-    int ret          = CL_VIRUS;
-    struct CACHE *c;
+    const char *errmsg = NULL;
 
-    c = &cache[key];
-#ifdef CL_THREAD_SAFE
-    if (pthread_mutex_lock(&c->mutex)) {
-        cli_errmsg("cache_lookup_hash: cache_lookup_hash: mutex lock fail\n");
-        return ret;
-    }
-#endif
-
-    /* cli_warnmsg("cache_lookup_hash: key is %u\n", key); */
-
-    ret = (cacheset_lookup(&c->cacheset, md5, len, recursion_level)) ? CL_CLEAN : CL_VIRUS;
-#ifdef CL_THREAD_SAFE
-    pthread_mutex_unlock(&c->mutex);
-    // if(ret == CL_CLEAN) cli_warnmsg("cached\n");
-#endif
-    return ret;
-}
-
-/* Adds an hash to the cache */
-void cache_add(unsigned char *md5, size_t size, cli_ctx *ctx)
-{
-    unsigned int key = getkey(md5);
+    unsigned int key = 0;
     uint32_t level;
     struct CACHE *c;
 
@@ -869,18 +646,40 @@ void cache_add(unsigned char *md5, size_t size, cli_ctx *ctx)
         return;
 
     if (ctx->engine->engine_options & ENGINE_OPTIONS_DISABLE_CACHE) {
-        cli_dbgmsg("cache_add: Caching disabled. Not adding sample to cache.\n");
+        cli_dbgmsg("clean_cache_add: Caching disabled. Not adding sample to cache.\n");
+        return;
+    }
+
+    if (!md5) {
+        cli_dbgmsg("clean_cache_add: No hash available. Nothing to add to cache.\n");
+        return;
+    }
+
+    if (SCAN_COLLECT_METADATA) {
+        // Don't cache when using the "collect metadata" feature.
+        // We don't cache the JSON, so we can't reproduce it when the cache is positive.
+        cli_dbgmsg("clean_cache_add: collect metadata feature enabled, skipping cache\n");
+        return;
+    }
+
+    if (ctx->fmap && ctx->fmap->dont_cache_flag == true) {
+        cli_dbgmsg("clean_cache_add: caching disabled for this layer, skipping cache\n");
+        return;
+    }
+
+    if (0 < evidence_num_alerts(ctx->evidence)) {
+        // TODO: The dont cache flag should take care of preventing caching of files with embedded files that alert.
+        //       Consider removing this check to allow caching of other actually clean files found within archives.
+        //       It would be a (very) minor optimization.
+        cli_dbgmsg("clean_cache_add: alert found within same topfile, skipping cache\n");
         return;
     }
 
     level = (ctx->fmap && ctx->fmap->dont_cache_flag) ? ctx->recursion_level : 0;
-    if (ctx->found_possibly_unwanted && (level || 0 == ctx->recursion_level))
-        return;
-    if (SCAN_ALLMATCHES && (ctx->num_viruses > 0)) {
-        cli_dbgmsg("cache_add: alert found within same topfile, skipping cache\n");
-        return;
-    }
-    c = &ctx->engine->cache[key];
+
+    key = getkey(md5, ctx->engine->cache->trees);
+    c   = &ctx->engine->cache[key];
+
 #ifdef CL_THREAD_SAFE
     if (pthread_mutex_lock(&c->mutex)) {
         cli_errmsg("cli_add: mutex lock fail\n");
@@ -888,40 +687,39 @@ void cache_add(unsigned char *md5, size_t size, cli_ctx *ctx)
     }
 #endif
 
-    /* cli_warnmsg("cache_add: key is %u\n", key); */
-
-#ifdef USE_LRUHASHCACHE
-    cacheset_add(&c->cacheset, md5, size, ctx->engine->mempool);
-#else
-#ifdef USE_SPLAY
-    cacheset_add(&c->cacheset, md5, size, level);
-#else
-#error #define USE_SPLAY or USE_LRUHASHCACHE
-#endif
-#endif
+    errmsg = cacheset_add(&c->cacheset, md5, size, level);
 
 #ifdef CL_THREAD_SAFE
     pthread_mutex_unlock(&c->mutex);
 #endif
-    cli_dbgmsg("cache_add: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x (level %u)\n", md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7], md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15], level);
+    if (errmsg != NULL) {
+        cli_errmsg("%s\n", errmsg);
+    }
+
+    cli_dbgmsg("clean_cache_add: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x (level %u)\n", md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7], md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15], level);
+
     return;
 }
 
-/* Removes a hash from the cache */
-void cache_remove(unsigned char *md5, size_t size, const struct cl_engine *engine)
+void clean_cache_remove(unsigned char *md5, size_t size, const struct cl_engine *engine)
 {
-    unsigned int key = getkey(md5);
+    unsigned int key = 0;
     struct CACHE *c;
 
     if (!engine || !engine->cache)
         return;
 
     if (engine->engine_options & ENGINE_OPTIONS_DISABLE_CACHE) {
-        cli_dbgmsg("cache_remove: Caching disabled.\n");
+        cli_dbgmsg("clean_cache_remove: Caching disabled.\n");
         return;
     }
 
-    /* cli_warnmsg("cache_remove: key is %u\n", key); */
+    if (!md5) {
+        cli_dbgmsg("clean_cache_remove: No hash available. Nothing to remove from cache.\n");
+        return;
+    }
+
+    key = getkey(md5, engine->cache->trees);
 
     c = &engine->cache[key];
 #ifdef CL_THREAD_SAFE
@@ -931,41 +729,30 @@ void cache_remove(unsigned char *md5, size_t size, const struct cl_engine *engin
     }
 #endif
 
-#ifdef USE_LRUHASHCACHE
-    cacheset_remove(&c->cacheset, md5, size, engine->mempool);
-#else
-#ifdef USE_SPLAY
     cacheset_remove(&c->cacheset, md5, size);
-#else
-#error #define USE_SPLAY or USE_LRUHASHCACHE
-#endif
-#endif
 
 #ifdef CL_THREAD_SAFE
     pthread_mutex_unlock(&c->mutex);
 #endif
-    cli_dbgmsg("cache_remove: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x\n", md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7], md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15]);
+    cli_dbgmsg("clean_cache_remove: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x\n", md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7], md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15]);
     return;
 }
 
-/* Hashes a file onto the provided buffer and looks it up the cache.
-   Returns CL_VIRUS if found, CL_CLEAN if not FIXME or a recoverable error,
-   and returns CL_EREAD if unrecoverable */
-cl_error_t cache_check(unsigned char *hash, cli_ctx *ctx)
+cl_error_t clean_cache_check(unsigned char *md5, size_t size, cli_ctx *ctx)
 {
-    fmap_t *map;
     int ret;
 
     if (!ctx || !ctx->engine || !ctx->engine->cache)
         return CL_VIRUS;
 
-    if (ctx->engine->engine_options & ENGINE_OPTIONS_DISABLE_CACHE) {
-        cli_dbgmsg("cache_check: Caching disabled. Returning CL_VIRUS.\n");
+    if (SCAN_COLLECT_METADATA) {
+        // Don't cache when using the "collect metadata" feature.
+        // We don't cache the JSON, so we can't reproduce it when the cache is positive.
+        cli_dbgmsg("clean_cache_check: collect metadata feature enabled, skipping cache\n");
         return CL_VIRUS;
     }
 
-    map = ctx->fmap;
-    ret = cache_lookup_hash(hash, map->len, ctx->engine->cache, ctx->recursion_level);
-    cli_dbgmsg("cache_check: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x is %s\n", hash[0], hash[1], hash[2], hash[3], hash[4], hash[5], hash[6], hash[7], hash[8], hash[9], hash[10], hash[11], hash[12], hash[13], hash[14], hash[15], (ret == CL_VIRUS) ? "negative" : "positive");
+    ret = cache_lookup_hash(md5, size, ctx->engine->cache, ctx->recursion_level);
+    cli_dbgmsg("clean_cache_check: %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x is %s\n", md5[0], md5[1], md5[2], md5[3], md5[4], md5[5], md5[6], md5[7], md5[8], md5[9], md5[10], md5[11], md5[12], md5[13], md5[14], md5[15], (ret == CL_VIRUS) ? "negative" : "positive");
     return ret;
 }
