@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2008-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm
@@ -34,27 +34,29 @@
 #define CLI_DEFAULT_BM_OFFMODE_FSIZE 262144
 
 #define CLI_DEFAULT_TIMELIMIT     (1000 * 60 * 2)       // 2 minutes
-#define CLI_DEFAULT_MAXSCANSIZE   (1024 * 1024 * 100)   // 100 MB
-#define CLI_DEFAULT_MAXFILESIZE   (1024 * 1024 * 25)    // 25 MB
+#define CLI_DEFAULT_MAXSCANSIZE   (1024 * 1024 * 400)   // 400 MB
+#define CLI_DEFAULT_MAXFILESIZE   (1024 * 1024 * 100)   // 100 MB
 #define CLI_DEFAULT_MAXRECLEVEL   17
 #define CLI_DEFAULT_MAXFILES      10000
 #define CLI_DEFAULT_MIN_CC_COUNT  3
 #define CLI_DEFAULT_MIN_SSN_COUNT 3
 
-#define CLI_DEFAULT_MAXEMBEDDEDPE      10485760
-#define CLI_DEFAULT_MAXHTMLNORMALIZE   10485760
-#define CLI_DEFAULT_MAXHTMLNOTAGS      2097152
-#define CLI_DEFAULT_MAXSCRIPTNORMALIZE 5242880
-#define CLI_DEFAULT_MAXZIPTYPERCG      1048576
+#define CLI_DEFAULT_MAXEMBEDDEDPE      (1024 * 1024 * 40)   // 40 MB
+#define CLI_DEFAULT_MAXHTMLNORMALIZE   (1024 * 1024 * 40)   // 40 MB
+#define CLI_DEFAULT_MAXHTMLNOTAGS      (1024 * 1024 * 8)    // 8 MB
+#define CLI_DEFAULT_MAXSCRIPTNORMALIZE (1024 * 1024 * 20)   // 20 MB
+#define CLI_DEFAULT_MAXZIPTYPERCG      (1024 * 1024 * 1)    // 1 MB
 #define CLI_DEFAULT_MAXICONSPE         100
 #define CLI_DEFAULT_MAXRECHWP3         16
 
 #define CLI_DEFAULT_MAXPARTITIONS 50
 
+#define CLI_DEFAULT_CACHE_SIZE 65536
+
 /* TODO - set better defaults */
 #define CLI_DEFAULT_PCRE_MATCH_LIMIT    100000
 #define CLI_DEFAULT_PCRE_RECMATCH_LIMIT 2000
-#define CLI_DEFAULT_PCRE_MAX_FILESIZE   26214400
+#define CLI_DEFAULT_PCRE_MAX_FILESIZE   (1024 * 1024 * 100)   // 100 MB
 
 // clang-format on
 
