@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm
@@ -56,88 +56,93 @@ static const struct ftmap_s {
     const char *name;
     cli_file_t code;
 } ftmap[] = {
-    { "CL_TYPE_TEXT_ASCII",   CL_TYPE_TEXT_ASCII   },
-    { "CL_TYPE_TEXT_UTF8",    CL_TYPE_TEXT_UTF8    },
-    { "CL_TYPE_TEXT_UTF16LE", CL_TYPE_TEXT_UTF16LE },
-    { "CL_TYPE_TEXT_UTF16BE", CL_TYPE_TEXT_UTF16BE },
-    { "CL_TYPE_BINARY_DATA",  CL_TYPE_BINARY_DATA  },
-    { "CL_TYPE_IGNORED",      CL_TYPE_IGNORED      },
-    { "CL_TYPE_ANY",          CL_TYPE_ANY          },
-    { "CL_TYPE_MSEXE",        CL_TYPE_MSEXE        },
-    { "CL_TYPE_ELF",          CL_TYPE_ELF          },
-    { "CL_TYPE_MACHO",        CL_TYPE_MACHO        },
-    { "CL_TYPE_MACHO_UNIBIN", CL_TYPE_MACHO_UNIBIN },
-    { "CL_TYPE_POSIX_TAR",    CL_TYPE_POSIX_TAR    },
-    { "CL_TYPE_OLD_TAR",      CL_TYPE_OLD_TAR      },
-    { "CL_TYPE_CPIO_OLD",     CL_TYPE_CPIO_OLD     },
-    { "CL_TYPE_CPIO_ODC",     CL_TYPE_CPIO_ODC     },
-    { "CL_TYPE_CPIO_NEWC",    CL_TYPE_CPIO_NEWC    },
-    { "CL_TYPE_CPIO_CRC",     CL_TYPE_CPIO_CRC     },
-    { "CL_TYPE_GZ",           CL_TYPE_GZ           },
-    { "CL_TYPE_ZIP",          CL_TYPE_ZIP          },
-    { "CL_TYPE_BZ",           CL_TYPE_BZ           },
-    { "CL_TYPE_RAR",          CL_TYPE_RAR          },
-    { "CL_TYPE_ARJ",          CL_TYPE_ARJ          },
-    { "CL_TYPE_MSSZDD",       CL_TYPE_MSSZDD       },
-    { "CL_TYPE_MSOLE2",       CL_TYPE_MSOLE2       },
-    { "CL_TYPE_MSCAB",        CL_TYPE_MSCAB        },
-    { "CL_TYPE_MSCHM",        CL_TYPE_MSCHM        },
-    { "CL_TYPE_SIS",          CL_TYPE_SIS          },
-    { "CL_TYPE_SCRENC",       CL_TYPE_SCRENC       },
-    { "CL_TYPE_GRAPHICS",     CL_TYPE_GRAPHICS     },
-    { "CL_TYPE_GIF",          CL_TYPE_GIF          },
-    { "CL_TYPE_PNG",          CL_TYPE_PNG          },
-    { "CL_TYPE_JPEG",         CL_TYPE_JPEG         },
-    { "CL_TYPE_TIFF",         CL_TYPE_TIFF         },
-    { "CL_TYPE_RIFF",         CL_TYPE_RIFF         },
-    { "CL_TYPE_BINHEX",       CL_TYPE_BINHEX       },
-    { "CL_TYPE_TNEF",         CL_TYPE_TNEF         },
-    { "CL_TYPE_CRYPTFF",      CL_TYPE_CRYPTFF      },
-    { "CL_TYPE_PDF",          CL_TYPE_PDF          },
-    { "CL_TYPE_UUENCODED",    CL_TYPE_UUENCODED    },
-    { "CL_TYPE_HTML_UTF16",   CL_TYPE_HTML_UTF16   },
-    { "CL_TYPE_SCRIPT",       CL_TYPE_SCRIPT       },
-    { "CL_TYPE_RTF",          CL_TYPE_RTF          },
-    { "CL_TYPE_HTML",         CL_TYPE_HTML         },
-    { "CL_TYPE_MAIL",         CL_TYPE_MAIL         },
-    { "CL_TYPE_SFX",          CL_TYPE_SFX          },
-    { "CL_TYPE_ZIPSFX",       CL_TYPE_ZIPSFX       },
-    { "CL_TYPE_RARSFX",       CL_TYPE_RARSFX       },
-    { "CL_TYPE_CABSFX",       CL_TYPE_CABSFX       },
-    { "CL_TYPE_ARJSFX",       CL_TYPE_ARJSFX       },
-    { "CL_TYPE_NULSFT",       CL_TYPE_NULSFT       },
-    { "CL_TYPE_AUTOIT",       CL_TYPE_AUTOIT       },
-    { "CL_TYPE_ISHIELD_MSI",  CL_TYPE_ISHIELD_MSI  },
-    { "CL_TYPE_7Z",           CL_TYPE_7Z           },
-    { "CL_TYPE_7ZSFX",        CL_TYPE_7ZSFX        },
-    { "CL_TYPE_SWF",          CL_TYPE_SWF          },
-    { "CL_TYPE_ISO9660",      CL_TYPE_ISO9660      },
-    { "CL_TYPE_JAVA",         CL_TYPE_JAVA         },
-    { "CL_TYPE_DMG",          CL_TYPE_DMG          },
-    { "CL_TYPE_MBR",          CL_TYPE_MBR          },
-    { "CL_TYPE_GPT",          CL_TYPE_GPT          },
-    { "CL_TYPE_APM",          CL_TYPE_APM          },
-    { "CL_TYPE_XAR",          CL_TYPE_XAR          },
-    { "CL_TYPE_PART_ANY",     CL_TYPE_PART_ANY     },
-    { "CL_TYPE_PART_HFSPLUS", CL_TYPE_PART_HFSPLUS },
-    { "CL_TYPE_XZ",           CL_TYPE_XZ           },
-    { "CL_TYPE_OOXML_WORD",   CL_TYPE_OOXML_WORD   },
-    { "CL_TYPE_OOXML_PPT",    CL_TYPE_OOXML_PPT    },
-    { "CL_TYPE_OOXML_XL",     CL_TYPE_OOXML_XL     },
-    { "CL_TYPE_INTERNAL",     CL_TYPE_INTERNAL     },
-    { "CL_TYPE_XDP",          CL_TYPE_XDP          },
-    { "CL_TYPE_XML_WORD",     CL_TYPE_XML_WORD     },
-    { "CL_TYPE_XML_XL",       CL_TYPE_XML_XL       },
-    { "CL_TYPE_HWP3",         CL_TYPE_HWP3         },
-    { "CL_TYPE_XML_HWP",      CL_TYPE_XML_HWP      },
-    { "CL_TYPE_HWPOLE2",      CL_TYPE_HWPOLE2      },
-    { "CL_TYPE_OOXML_HWP",    CL_TYPE_OOXML_HWP    },
-    { "CL_TYPE_PS",           CL_TYPE_PS           },
-    { "CL_TYPE_MHTML",        CL_TYPE_MHTML        },
-    { "CL_TYPE_LNK",          CL_TYPE_LNK          },
-    { "CL_TYPE_EGG",          CL_TYPE_EGG          },
-    { "CL_TYPE_EGGSFX",       CL_TYPE_EGGSFX       },
-    { NULL,                   CL_TYPE_IGNORED      }
+    { "CL_TYPE_TEXT_ASCII",         CL_TYPE_TEXT_ASCII      },
+    { "CL_TYPE_TEXT_UTF8",          CL_TYPE_TEXT_UTF8       },
+    { "CL_TYPE_TEXT_UTF16LE",       CL_TYPE_TEXT_UTF16LE    },
+    { "CL_TYPE_TEXT_UTF16BE",       CL_TYPE_TEXT_UTF16BE    },
+    { "CL_TYPE_BINARY_DATA",        CL_TYPE_BINARY_DATA     },
+    { "CL_TYPE_IGNORED",            CL_TYPE_IGNORED         },
+    { "CL_TYPE_ANY",                CL_TYPE_ANY             },
+    { "CL_TYPE_MSEXE",              CL_TYPE_MSEXE           },
+    { "CL_TYPE_ELF",                CL_TYPE_ELF             },
+    { "CL_TYPE_MACHO",              CL_TYPE_MACHO           },
+    { "CL_TYPE_MACHO_UNIBIN",       CL_TYPE_MACHO_UNIBIN    },
+    { "CL_TYPE_POSIX_TAR",          CL_TYPE_POSIX_TAR       },
+    { "CL_TYPE_OLD_TAR",            CL_TYPE_OLD_TAR         },
+    { "CL_TYPE_CPIO_OLD",           CL_TYPE_CPIO_OLD        },
+    { "CL_TYPE_CPIO_ODC",           CL_TYPE_CPIO_ODC        },
+    { "CL_TYPE_CPIO_NEWC",          CL_TYPE_CPIO_NEWC       },
+    { "CL_TYPE_CPIO_CRC",           CL_TYPE_CPIO_CRC        },
+    { "CL_TYPE_GZ",                 CL_TYPE_GZ              },
+    { "CL_TYPE_ZIP",                CL_TYPE_ZIP             },
+    { "CL_TYPE_BZ",                 CL_TYPE_BZ              },
+    { "CL_TYPE_RAR",                CL_TYPE_RAR             },
+    { "CL_TYPE_ARJ",                CL_TYPE_ARJ             },
+    { "CL_TYPE_MSSZDD",             CL_TYPE_MSSZDD          },
+    { "CL_TYPE_MSOLE2",             CL_TYPE_MSOLE2          },
+    { "CL_TYPE_MSCAB",              CL_TYPE_MSCAB           },
+    { "CL_TYPE_MSCHM",              CL_TYPE_MSCHM           },
+    { "CL_TYPE_SIS",                CL_TYPE_SIS             },
+    { "CL_TYPE_SCRENC",             CL_TYPE_SCRENC          },
+    { "CL_TYPE_GRAPHICS",           CL_TYPE_GRAPHICS        },
+    { "CL_TYPE_GIF",                CL_TYPE_GIF             },
+    { "CL_TYPE_PNG",                CL_TYPE_PNG             },
+    { "CL_TYPE_JPEG",               CL_TYPE_JPEG            },
+    { "CL_TYPE_TIFF",               CL_TYPE_TIFF            },
+    { "CL_TYPE_RIFF",               CL_TYPE_RIFF            },
+    { "CL_TYPE_BINHEX",             CL_TYPE_BINHEX          },
+    { "CL_TYPE_TNEF",               CL_TYPE_TNEF            },
+    { "CL_TYPE_CRYPTFF",            CL_TYPE_CRYPTFF         },
+    { "CL_TYPE_PDF",                CL_TYPE_PDF             },
+    { "CL_TYPE_UUENCODED",          CL_TYPE_UUENCODED       },
+    { "CL_TYPE_HTML_UTF16",         CL_TYPE_HTML_UTF16      },
+    { "CL_TYPE_SCRIPT",             CL_TYPE_SCRIPT          },
+    { "CL_TYPE_RTF",                CL_TYPE_RTF             },
+    { "CL_TYPE_HTML",               CL_TYPE_HTML            },
+    { "CL_TYPE_MAIL",               CL_TYPE_MAIL            },
+    { "CL_TYPE_SFX",                CL_TYPE_SFX             },
+    { "CL_TYPE_ZIPSFX",             CL_TYPE_ZIPSFX          },
+    { "CL_TYPE_RARSFX",             CL_TYPE_RARSFX          },
+    { "CL_TYPE_CABSFX",             CL_TYPE_CABSFX          },
+    { "CL_TYPE_ARJSFX",             CL_TYPE_ARJSFX          },
+    { "CL_TYPE_NULSFT",             CL_TYPE_NULSFT          },
+    { "CL_TYPE_AUTOIT",             CL_TYPE_AUTOIT          },
+    { "CL_TYPE_ISHIELD_MSI",        CL_TYPE_ISHIELD_MSI     },
+    { "CL_TYPE_7Z",                 CL_TYPE_7Z              },
+    { "CL_TYPE_7ZSFX",              CL_TYPE_7ZSFX           },
+    { "CL_TYPE_SWF",                CL_TYPE_SWF             },
+    { "CL_TYPE_ISO9660",            CL_TYPE_ISO9660         },
+    { "CL_TYPE_JAVA",               CL_TYPE_JAVA            },
+    { "CL_TYPE_DMG",                CL_TYPE_DMG             },
+    { "CL_TYPE_MBR",                CL_TYPE_MBR             },
+    { "CL_TYPE_GPT",                CL_TYPE_GPT             },
+    { "CL_TYPE_APM",                CL_TYPE_APM             },
+    { "CL_TYPE_XAR",                CL_TYPE_XAR             },
+    { "CL_TYPE_PART_ANY",           CL_TYPE_PART_ANY        },
+    { "CL_TYPE_PART_HFSPLUS",       CL_TYPE_PART_HFSPLUS    },
+    { "CL_TYPE_XZ",                 CL_TYPE_XZ              },
+    { "CL_TYPE_OOXML_WORD",         CL_TYPE_OOXML_WORD      },
+    { "CL_TYPE_OOXML_PPT",          CL_TYPE_OOXML_PPT       },
+    { "CL_TYPE_OOXML_XL",           CL_TYPE_OOXML_XL        },
+    { "CL_TYPE_INTERNAL",           CL_TYPE_INTERNAL        },
+    { "CL_TYPE_XDP",                CL_TYPE_XDP             },
+    { "CL_TYPE_XML_WORD",           CL_TYPE_XML_WORD        },
+    { "CL_TYPE_XML_XL",             CL_TYPE_XML_XL          },
+    { "CL_TYPE_HWP3",               CL_TYPE_HWP3            },
+    { "CL_TYPE_XML_HWP",            CL_TYPE_XML_HWP         },
+    { "CL_TYPE_HWPOLE2",            CL_TYPE_HWPOLE2         },
+    { "CL_TYPE_OOXML_HWP",          CL_TYPE_OOXML_HWP       },
+    { "CL_TYPE_PS",                 CL_TYPE_PS              },
+    { "CL_TYPE_MHTML",              CL_TYPE_MHTML           },
+    { "CL_TYPE_LNK",                CL_TYPE_LNK             },
+    { "CL_TYPE_EGG",                CL_TYPE_EGG             },
+    { "CL_TYPE_EGGSFX",             CL_TYPE_EGGSFX          },
+    { "CL_TYPE_UDF",                CL_TYPE_UDF             },
+    { "CL_TYPE_ALZ",                CL_TYPE_ALZ             },
+    { "CL_TYPE_ONENOTE",            CL_TYPE_ONENOTE         },
+    { "CL_TYPE_PYTHON_COMPILED",    CL_TYPE_PYTHON_COMPILED },
+    { "CL_TYPE_LHA_LZH",            CL_TYPE_LHA_LZH         },
+    { NULL,                         CL_TYPE_IGNORED         }
 };
 // clang-format on
 
