@@ -1,7 +1,7 @@
 /*
  *  Support for matcher using PCRE
  *
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Kevin Lin
@@ -44,7 +44,6 @@ struct cli_pcre_off {
     uint32_t *offset, *shift;
 };
 
-#if HAVE_PCRE
 #define PCRE_BYPASS "7374756c747a676574737265676578"
 #define CLI_PCRE_GLOBAL 0x00000001    /* g */
 #define CLI_PCRE_ENCOMPASS 0x00000002 /* e */
@@ -54,7 +53,6 @@ struct cli_pcre_off {
 
 struct cli_pcre_meta {
     char *trigger;
-    char *virname;
     uint32_t lsigid[3]; /* 0=valid, 1=lsigid, 2=subsigid */
     struct cli_pcre_data pdata;
     /* clamav offset data */
@@ -67,30 +65,16 @@ struct cli_pcre_meta {
     uint32_t sigtime_id, sigmatch_id;
 };
 
-/* PCRE PERFORMANCE DECLARATIONS */
+cl_error_t cli_pcre_addpatt(struct cli_matcher *root, const char *virname, const char *trigger, const char *pattern, const char *cflags, const char *offset, const uint32_t *lsigid, unsigned int options);
+void cli_pcre_freemeta(struct cli_matcher *root, struct cli_pcre_meta *pm);
+void cli_pcre_freetable(struct cli_matcher *root);
+
+cl_error_t cli_pcre_build(struct cli_matcher *root, long long unsigned match_limit, long long unsigned recmatch_limit, const struct cli_dconf *dconf);
+cl_error_t cli_pcre_scanbuf(const unsigned char *buffer, uint32_t length, const char **virname, struct cli_ac_result **res, const struct cli_matcher *root, struct cli_ac_data *mdata, const struct cli_pcre_off *data, cli_ctx *ctx);
+cl_error_t cli_pcre_recaloff(struct cli_matcher *root, struct cli_pcre_off *data, struct cli_target_info *info, cli_ctx *ctx);
+void cli_pcre_freeoff(struct cli_pcre_off *data);
+
 void cli_pcre_perf_print(void);
 void cli_pcre_perf_events_destroy(void);
 
-/* PCRE MATCHER DECLARATIONS */
-int cli_pcre_init(void);
-cl_error_t cli_pcre_addpatt(struct cli_matcher *root, const char *virname, const char *trigger, const char *pattern, const char *cflags, const char *offset, const uint32_t *lsigid, unsigned int options);
-cl_error_t cli_pcre_build(struct cli_matcher *root, long long unsigned match_limit, long long unsigned recmatch_limit, const struct cli_dconf *dconf);
-cl_error_t cli_pcre_recaloff(struct cli_matcher *root, struct cli_pcre_off *data, struct cli_target_info *info, cli_ctx *ctx);
-void cli_pcre_freeoff(struct cli_pcre_off *data);
-cl_error_t cli_pcre_scanbuf(const unsigned char *buffer, uint32_t length, const char **virname, struct cli_ac_result **res, const struct cli_matcher *root, struct cli_ac_data *mdata, const struct cli_pcre_off *data, cli_ctx *ctx);
-void cli_pcre_freemeta(struct cli_matcher *root, struct cli_pcre_meta *pm);
-void cli_pcre_freetable(struct cli_matcher *root);
-#else
-/* NO-PCRE DECLARATIONS - defined because encasing everything in '#if' is a pain and because dynamic library mappings are weird */
-#define PCRE_BYPASS ""
-
-void cli_pcre_perf_print();
-void cli_pcre_perf_events_destroy();
-
-int cli_pcre_init();
-int cli_pcre_build(struct cli_matcher *root, long long unsigned match_limit, long long unsigned recmatch_limit, const struct cli_dconf *dconf);
-int cli_pcre_scanbuf(const unsigned char *buffer, uint32_t length, const char **virname, struct cli_ac_result **res, const struct cli_matcher *root, struct cli_ac_data *mdata, const struct cli_pcre_off *data, cli_ctx *ctx);
-int cli_pcre_recaloff(struct cli_matcher *root, struct cli_pcre_off *data, struct cli_target_info *info, cli_ctx *ctx);
-void cli_pcre_freeoff(struct cli_pcre_off *data);
-#endif /* HAVE_PCRE */
 #endif /*__MATCHER_PCRE_H*/
