@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Nigel Horne
@@ -140,7 +140,7 @@ static const unsigned char base64Table[256] = {
 message *
 messageCreate(void)
 {
-    message *m = (message *)cli_calloc(1, sizeof(message));
+    message *m = (message *)calloc(1, sizeof(message));
 
     if (m)
         m->mimeType = NOMIME;
@@ -194,10 +194,8 @@ void messageReset(message *m)
         free(m->encodingTypes);
     }
 
-#if HAVE_JSON
     if (m->jobj)
         cli_json_delobj(m->jobj);
-#endif
 
     memset(m, '\0', sizeof(message));
     m->mimeType = NOMIME;
@@ -343,7 +341,7 @@ void messageSetMimeSubtype(message *m, const char *subtype)
     if (m->mimeSubtype)
         free(m->mimeSubtype);
 
-    m->mimeSubtype = cli_strdup(subtype);
+    m->mimeSubtype = cli_safer_strdup(subtype);
 }
 
 const char *
@@ -375,7 +373,7 @@ void messageSetDispositionType(message *m, const char *disptype)
     while (*disptype && isspace((int)*disptype))
         disptype++;
     if (*disptype) {
-        m->mimeDispositionType = cli_strdup(disptype);
+        m->mimeDispositionType = cli_safer_strdup(disptype);
         if (m->mimeDispositionType)
             strstrip(m->mimeDispositionType);
     } else
@@ -430,7 +428,7 @@ void messageAddArgument(message *m, const char *arg)
         char **q;
 
         m->numberOfArguments++;
-        q = (char **)cli_realloc(m->mimeArguments, m->numberOfArguments * sizeof(char *));
+        q = (char **)cli_max_realloc(m->mimeArguments, m->numberOfArguments * sizeof(char *));
         if (q == NULL) {
             m->numberOfArguments--;
             return;
@@ -558,7 +556,7 @@ void messageAddArguments(message *m, const char *s)
              * The field is in quotes, so look for the
              * closing quotes
              */
-            kcopy = cli_strdup(key);
+            kcopy = cli_safer_strdup(key);
 
             if (kcopy == NULL)
                 return;
@@ -588,7 +586,7 @@ void messageAddArguments(message *m, const char *s)
                 continue;
             }
 
-            data = cli_strdup(cptr);
+            data = cli_safer_strdup(cptr);
 
             if (!data) {
                 cli_dbgmsg("Can't parse header \"%s\" - if you believe this file contains a missed virus, report it to bugs@clamav.net\n", s);
@@ -613,7 +611,7 @@ void messageAddArguments(message *m, const char *s)
                 *ptr = '\0';
 
             datasz = strlen(kcopy) + strlen(data) + 2;
-            field  = cli_realloc(kcopy, strlen(kcopy) + strlen(data) + 2);
+            field  = cli_max_realloc(kcopy, strlen(kcopy) + strlen(data) + 2);
             if (field) {
                 cli_strlcat(field, "=", datasz);
                 cli_strlcat(field, data, datasz);
@@ -637,7 +635,7 @@ void messageAddArguments(message *m, const char *s)
                 string++;
 
             len   = (size_t)string - (size_t)key + 1;
-            field = cli_malloc(len);
+            field = cli_max_malloc(len);
 
             if (field) {
                 memcpy(field, key, len - 1);
@@ -704,7 +702,7 @@ messageFindArgument(const message *m, const char *variable)
             ptr++;
             if ((strlen(ptr) > 1) && (*ptr == '"') && (strchr(&ptr[1], '"') != NULL)) {
                 /* Remove any quote characters */
-                char *ret = cli_strdup(++ptr);
+                char *ret = cli_safer_strdup(++ptr);
                 char *p;
 
                 if (ret == NULL)
@@ -725,7 +723,7 @@ messageFindArgument(const message *m, const char *variable)
                 }
                 return ret;
             }
-            return cli_strdup(ptr);
+            return cli_safer_strdup(ptr);
         }
     }
     return NULL;
@@ -857,7 +855,7 @@ void messageSetEncoding(message *m, const char *enctype)
                     break;
                 }
 
-                et = (encoding_type *)cli_realloc(m->encodingTypes, (m->numberOfEncTypes + 1) * sizeof(encoding_type));
+                et = (encoding_type *)cli_max_realloc(m->encodingTypes, (m->numberOfEncTypes + 1) * sizeof(encoding_type));
                 if (et == NULL)
                     break;
 
@@ -920,9 +918,9 @@ int messageAddLine(message *m, line_t *line)
     }
 
     if (m->body_first == NULL)
-        m->body_last = m->body_first = (text *)cli_malloc(sizeof(text));
+        m->body_last = m->body_first = (text *)malloc(sizeof(text));
     else {
-        m->body_last->t_next = (text *)cli_malloc(sizeof(text));
+        m->body_last->t_next = (text *)malloc(sizeof(text));
         m->body_last         = m->body_last->t_next;
     }
 
@@ -982,7 +980,7 @@ int messageAddStr(message *m, const char *data)
     }
 
     if (m->body_first == NULL)
-        m->body_last = m->body_first = (text *)cli_malloc(sizeof(text));
+        m->body_last = m->body_first = (text *)malloc(sizeof(text));
     else {
         if (m->body_last == NULL) {
             cli_errmsg("Internal email parser error: message 'body_last' pointer should not be NULL if 'body_first' is set.\n");
@@ -997,10 +995,10 @@ int messageAddStr(message *m, const char *data)
                     /* don't save two blank lines in succession */
                     return 1;
 
-            m->body_last->t_next = (text *)cli_malloc(sizeof(text));
+            m->body_last->t_next = (text *)malloc(sizeof(text));
             if (m->body_last->t_next == NULL) {
                 messageDedup(m);
-                m->body_last->t_next = (text *)cli_malloc(sizeof(text));
+                m->body_last->t_next = (text *)malloc(sizeof(text));
                 if (m->body_last->t_next == NULL) {
                     cli_errmsg("messageAddStr: out of memory\n");
                     return -1;
@@ -1278,7 +1276,7 @@ messageExport(message *m, const char *dir, void *(*create)(void), void (*destroy
             f      = lineGetData(t_line->t_line);
 
             if ((filename = strstr(f, " name=")) != NULL) {
-                filename = cli_strdup(&filename[6]);
+                filename = cli_safer_strdup(&filename[6]);
                 if (filename) {
                     cli_chomp(filename);
                     strstrip(filename);
@@ -1375,7 +1373,7 @@ messageExport(message *m, const char *dir, void *(*create)(void), void (*destroy
             datasize = (line) ? strlen(line) + 2 : 0;
 
             if (datasize >= sizeof(smallbuf)) {
-                data = bigbuf = (unsigned char *)cli_malloc(datasize);
+                data = bigbuf = (unsigned char *)cli_max_malloc(datasize);
                 if (NULL == data) {
                     cli_dbgmsg("Failed to allocate data buffer of size %zu\n", datasize);
                     break;
@@ -1550,9 +1548,9 @@ messageToText(message *m)
          */
         for (t_line = messageGetBody(m); t_line; t_line = t_line->t_next) {
             if (first == NULL)
-                first = last = cli_malloc(sizeof(text));
+                first = last = malloc(sizeof(text));
             else {
-                last->t_next = cli_malloc(sizeof(text));
+                last->t_next = malloc(sizeof(text));
                 last         = last->t_next;
             }
 
@@ -1590,9 +1588,9 @@ messageToText(message *m)
                  */
                 for (t_line = messageGetBody(m); t_line; t_line = t_line->t_next) {
                     if (first == NULL)
-                        first = last = cli_malloc(sizeof(text));
+                        first = last = malloc(sizeof(text));
                     else if (last) {
-                        last->t_next = cli_malloc(sizeof(text));
+                        last->t_next = malloc(sizeof(text));
                         last         = last->t_next;
                     }
 
@@ -1665,9 +1663,9 @@ messageToText(message *m)
             }
 
             if (first == NULL)
-                first = last = cli_malloc(sizeof(text));
+                first = last = malloc(sizeof(text));
             else if (last) {
-                last->t_next = cli_malloc(sizeof(text));
+                last->t_next = malloc(sizeof(text));
                 last         = last->t_next;
             }
 
@@ -1703,9 +1701,9 @@ messageToText(message *m)
             memset(data, '\0', sizeof(data));
             if (decode(m, NULL, data, base64, false) && data[0]) {
                 if (first == NULL)
-                    first = last = cli_malloc(sizeof(text));
+                    first = last = malloc(sizeof(text));
                 else if (last) {
-                    last->t_next = cli_malloc(sizeof(text));
+                    last->t_next = malloc(sizeof(text));
                     last         = last->t_next;
                 }
 
@@ -1903,7 +1901,7 @@ decodeLine(message *m, encoding_type et, const char *line, unsigned char *buf, s
                 strcpy(base64buf, line);
                 copy = base64buf;
             } else {
-                copy = cli_strdup(line);
+                copy = cli_safer_strdup(line);
                 if (copy == NULL)
                     break;
             }
@@ -2338,7 +2336,7 @@ rfc2231(const char *in)
         char *p;
 
         /* Don't handle continuations, decode what we can */
-        p = ret = cli_malloc(strlen(in) + 16);
+        p = ret = cli_max_malloc(strlen(in) + 16);
         if (ret == NULL) {
             cli_errmsg("rfc2331: out of memory, unable to proceed\n");
             return NULL;
@@ -2386,7 +2384,7 @@ rfc2231(const char *in)
     }
 
     if (ptr == NULL) { /* quick return */
-        out = ret = cli_strdup(in);
+        out = ret = cli_safer_strdup(in);
         while (*out)
             *out++ &= 0x7F;
         return ret;
@@ -2394,7 +2392,7 @@ rfc2231(const char *in)
 
     cli_dbgmsg("rfc2231 '%s'\n", in);
 
-    ret = cli_malloc(strlen(in) + 1);
+    ret = cli_max_malloc(strlen(in) + 1);
 
     if (ret == NULL) {
         cli_errmsg("rfc2331: out of memory for ret\n");
@@ -2461,7 +2459,7 @@ rfc2231(const char *in)
     if (field != CONTENTS) {
         free(ret);
         cli_dbgmsg("Invalid RFC2231 header: '%s'\n", in);
-        return cli_strdup("");
+        return cli_safer_strdup("");
     }
 
     *out = '\0';
@@ -2509,9 +2507,9 @@ simil(const char *str1, const char *str2)
     if (strcasecmp(str1, str2) == 0)
         return 100;
 
-    if ((s1 = cli_strdup(str1)) == NULL)
+    if ((s1 = cli_safer_strdup(str1)) == NULL)
         return OUT_OF_MEMORY;
-    if ((s2 = cli_strdup(str2)) == NULL) {
+    if ((s2 = cli_safer_strdup(str2)) == NULL) {
         free(s1);
         return OUT_OF_MEMORY;
     }
@@ -2627,9 +2625,9 @@ push(LINK1 *top, const char *string)
 {
     LINK1 element;
 
-    if ((element = (LINK1)cli_malloc(sizeof(ELEMENT1))) == NULL)
+    if ((element = (LINK1)malloc(sizeof(ELEMENT1))) == NULL)
         return OUT_OF_MEMORY;
-    if ((element->d1 = cli_strdup(string)) == NULL) {
+    if ((element->d1 = cli_safer_strdup(string)) == NULL) {
         free(element);
         return OUT_OF_MEMORY;
     }
@@ -2670,7 +2668,6 @@ int isuuencodebegin(const char *line)
            isdigit(line[8]) && (line[9] == ' ');
 }
 
-#if HAVE_JSON
 json_object *messageGetJObj(message *m)
 {
     if (m == NULL) {
@@ -2682,4 +2679,3 @@ json_object *messageGetJObj(message *m)
 
     return m->jobj;
 }
-#endif
