@@ -1,7 +1,7 @@
 /*
  * Extract component parts of OLE2 files (e.g. MS Office Documents)
  *
- * Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ * Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  * Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  * Authors: Kevin Lin
@@ -49,9 +49,7 @@
 #include "json_api.h"
 #include "entconv.h"
 
-#if HAVE_JSON
-static char *
-ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encoding)
+static char *ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encoding)
 {
     char *outbuf = NULL;
 #if HAVE_ICONV
@@ -72,7 +70,7 @@ ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encodi
 
     if (sz == 0) {
         cli_dbgmsg("ole2_convert_utf: converting empty string\n");
-        return cli_calloc(1, 1); // Just send back an empty NULL-terminated string.
+        return calloc(1, 1); // Just send back an empty NULL-terminated string.
     }
 
     /* applies in the both case */
@@ -80,7 +78,7 @@ ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encodi
         char *track;
         size_t bcnt, scnt;
 
-        outbuf = cli_calloc(1, sz + 1);
+        outbuf = cli_max_calloc(1, sz + 1);
         if (!(outbuf))
             return NULL;
         memcpy(outbuf, begin, sz);
@@ -110,7 +108,7 @@ ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encodi
     }
 
 #if HAVE_ICONV
-    p1 = buf = cli_calloc(1, sz);
+    p1 = buf = cli_max_calloc(1, sz);
     if (!(buf))
         return NULL;
 
@@ -147,8 +145,8 @@ ole2_convert_utf(summary_ctx_t *sctx, char *begin, size_t sz, const char *encodi
         for (attempt = 1; attempt <= 3; ++attempt) {
             /* charset to UTF-8 should never exceed sz*6 */
             sz2 = (attempt * 2) * sz;
-            /* use cli_realloc, reuse the buffer that has already been translated */
-            outbuf = (char *)cli_realloc(outbuf, sz2 + 1);
+            /* use cli_max_realloc, reuse the buffer that has already been translated */
+            outbuf = (char *)cli_max_realloc(outbuf, sz2 + 1);
             if (!outbuf) {
                 free(buf);
                 iconv_close(cd);
@@ -428,7 +426,7 @@ ole2_process_property(summary_ctx_t *sctx, unsigned char *databuf, uint32_t offs
                     strsize = PROPSTRLIMIT;
                 }
 
-                outstr = cli_calloc(strsize + 1, 1); /* last char must be NULL */
+                outstr = cli_max_calloc(strsize + 1, 1); /* last char must be NULL */
                 if (!outstr) {
                     return CL_EMEM;
                 }
@@ -487,7 +485,7 @@ ole2_process_property(summary_ctx_t *sctx, unsigned char *databuf, uint32_t offs
                 sctx->flags |= OLE2_SUMMARY_ERROR_OOB;
                 return CL_EFORMAT;
             }
-            outstr = cli_calloc(strsize + 2, 1); /* last two chars must be NULL */
+            outstr = cli_max_calloc(strsize + 2, 1); /* last two chars must be NULL */
             if (!outstr) {
                 return CL_EMEM;
             }
@@ -998,4 +996,3 @@ int cli_ole2_summary_json(cli_ctx *ctx, int fd, int mode)
 
     return cli_ole2_summary_json_cleanup(&sctx, CL_SUCCESS);
 }
-#endif /* HAVE_JSON */
