@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Trog
@@ -50,9 +50,7 @@
 #include "scanners.h"
 #include "fmap.h"
 #include "json_api.h"
-#if HAVE_JSON
 #include "msdoc.h"
-#endif
 #include "rijndael.h"
 #include "ole2_encryption.h"
 
@@ -108,7 +106,7 @@ typedef struct ole2_header_tag {
      * The following is not part of the ole2 header, but stuff we need in
      * order to decode.
      *
-     * IMPORANT: These must take account of the size of variables below here
+     * IMPORTANT: These must take account of the size of variables below here
      * when calculating hdr_size to read the header.
      *
      * See the top of cli_ole2_extract().
@@ -196,8 +194,8 @@ int ole2_list_push(ole2_list_t *list, uint32_t val)
     ole2_list_node_t *new_node = NULL;
     int status                 = CL_EMEM;
 
-    CLI_MALLOC(new_node, sizeof(ole2_list_node_t),
-               cli_dbgmsg("OLE2: could not allocate new node for worklist!\n"));
+    CLI_MALLOC_OR_GOTO_DONE(new_node, sizeof(ole2_list_node_t),
+                            cli_dbgmsg("OLE2: could not allocate new node for worklist!\n"));
 
     new_node->Val  = val;
     new_node->Next = list->Head;
@@ -247,8 +245,14 @@ int ole2_list_delete(ole2_list_t *list)
 
 static unsigned char magic_id[] = {0xd0, 0xcf, 0x11, 0xe0, 0xa1, 0xb1, 0x1a, 0xe1};
 
-char *
-cli_ole2_get_property_name2(const char *name, int size)
+/**
+ * @brief Get the property name, converting to lower case and replacing non-printable characters.
+ *
+ * @param name   The property name
+ * @param size   The size of the property name
+ * @return char* The new property name
+ */
+char *cli_ole2_get_property_name2(const char *name, int size)
 {
     int i, j;
     char *newname = NULL;
@@ -256,27 +260,35 @@ cli_ole2_get_property_name2(const char *name, int size)
     if ((name[0] == 0 && name[1] == 0) || size <= 0 || size > 128) {
         return NULL;
     }
-    CLI_MALLOC(newname, size * 7,
-               cli_errmsg("OLE2 [cli_ole2_get_property_name2]: Unable to allocate memory for newname: %u\n", size * 7));
+
+    // We may need to replace every character with '_XY_' or '_XYZ_' to form a printable name.
+    // This is because the name may contain non-printable characters.
+    // Allocate 5 times the size of the name to be safe, plus 1 for the NULL terminator.
+    CLI_MAX_MALLOC_OR_GOTO_DONE(newname, size * 5 + 1,
+                                cli_errmsg("OLE2 [cli_ole2_get_property_name2]: Unable to allocate memory for newname: %u\n", size * 5));
 
     j = 0;
     /* size-2 to ignore trailing NULL */
     for (i = 0; i < size - 2; i += 2) {
-        if ((!(name[i] & 0x80)) && isprint(name[i]) && name[i + 1] == 0) {
+        if ((!(name[i] & 0x80)) &&
+            (isprint(name[i])) &&
+            (name[i + 1] == 0)) {
+            // Printable ASCII
             newname[j++] = tolower(name[i]);
         } else {
+            // Non-printable. Expand to something unique and printable.
             if (name[i] < 10 && name[i] >= 0 && name[i + 1] == 0) {
+                // Single digit (next byte is NULL)
                 newname[j++] = '_';
                 newname[j++] = name[i] + '0';
             } else {
+                // Two digits (next byte is not NULL)
                 const uint16_t x = (((uint16_t)name[i]) << 8) | name[i + 1];
 
                 newname[j++] = '_';
                 newname[j++] = 'a' + ((x & 0xF));
                 newname[j++] = 'a' + ((x >> 4) & 0xF);
                 newname[j++] = 'a' + ((x >> 8) & 0xF);
-                newname[j++] = 'a' + ((x >> 16) & 0xF);
-                newname[j++] = 'a' + ((x >> 24) & 0xF);
             }
             newname[j++] = '_';
         }
@@ -304,8 +316,8 @@ get_property_name(char *name, int size)
         return NULL;
     }
 
-    CLI_MALLOC(newname, size,
-               cli_errmsg("OLE2 [get_property_name]: Unable to allocate memory for newname %u\n", size));
+    CLI_MAX_MALLOC_OR_GOTO_DONE(newname, size,
+                                cli_errmsg("OLE2 [get_property_name]: Unable to allocate memory for newname %u\n", size));
     cname = newname;
 
     while (--csize) {
@@ -313,7 +325,7 @@ get_property_name(char *name, int size)
 
         oname += 2;
         if (u > 0x1040) {
-            FREE(newname);
+            CLI_FREE_AND_SET_NULL(newname);
             return cli_ole2_get_property_name2(name, size);
         }
         lo = u % 64;
@@ -597,10 +609,8 @@ static int ole2_walk_property_tree(ole2_header_t *hdr, const char *dir, int32_t
     char *dirname;
     ole2_list_t node_list;
     cl_error_t ret;
-#if HAVE_JSON
     char *name;
     int toval = 0;
-#endif
 
     ole2_listmsg("ole2_walk_property_tree() called\n");
     ole2_list_init(&node_list);
@@ -628,12 +638,11 @@ static int ole2_walk_property_tree(ole2_header_t *hdr, const char *dir, int32_t
 
     while (!ole2_list_is_empty(&node_list)) {
         ole2_listmsg("within working loop, worklist size: %d\n", ole2_list_size(&node_list));
-#if HAVE_JSON
+
         if (cli_json_timeout_cycle_check(ctx, &toval) != CL_SUCCESS) {
             ole2_list_delete(&node_list);
             return CL_ETIMEOUT;
         }
-#endif
 
         current_block = hdr->prop_start;
 
@@ -765,7 +774,6 @@ static int ole2_walk_property_tree(ole2_header_t *hdr, const char *dir, int32_t
             case 1: /* Directory */
                 ole2_listmsg("directory node\n");
                 if (dir) {
-#if HAVE_JSON
                     if (SCAN_COLLECT_METADATA && (ctx->wrkproperty != NULL)) {
                         if (!json_object_object_get_ex(ctx->wrkproperty, "DigitalSignatures", NULL)) {
                             name = cli_ole2_get_property_name2(prop_block[idx].name, prop_block[idx].name_size);
@@ -777,8 +785,8 @@ static int ole2_walk_property_tree(ole2_header_t *hdr, const char *dir, int32_t
                             }
                         }
                     }
-#endif
-                    dirname = (char *)cli_malloc(strlen(dir) + 8);
+
+                    dirname = (char *)cli_max_malloc(strlen(dir) + 8);
                     if (!dirname) {
                         ole2_listmsg("OLE2: malloc failed for dirname\n");
                         ole2_list_delete(&node_list);
@@ -888,9 +896,9 @@ static cl_error_t handler_writefile(ole2_header_t *hdr, property_t *prop, const
     current_block = prop->start_block;
     len           = prop->size;
 
-    CLI_MALLOC(buff, 1 << hdr->log2_big_block_size,
-               cli_errmsg("OLE2 [handler_writefile]: Unable to allocate memory for buff: %u\n", 1 << hdr->log2_big_block_size);
-               ret = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(buff, 1 << hdr->log2_big_block_size,
+                                cli_errmsg("OLE2 [handler_writefile]: Unable to allocate memory for buff: %u\n", 1 << hdr->log2_big_block_size);
+                                ret = CL_EMEM);
 
     blk_bitset = cli_bitset_init();
     if (!blk_bitset) {
@@ -956,11 +964,11 @@ static cl_error_t handler_writefile(ole2_header_t *hdr, property_t *prop, const
     ret = CL_SUCCESS;
 
 done:
-    FREE(name);
+    CLI_FREE_AND_SET_NULL(name);
     if (-1 != ofd) {
         close(ofd);
     }
-    FREE(buff);
+    CLI_FREE_AND_SET_NULL(buff);
     if (NULL != blk_bitset) {
         cli_bitset_free(blk_bitset);
     }
@@ -1048,7 +1056,6 @@ static cl_error_t scan_biff_for_xlm_macros_and_images(
             default:
                 switch (state->state) {
                     case BIFF_PARSER_NAME_RECORD:
-#if HAVE_JSON
                         if (state->data_offset == 0) {
                             state->tmp = buff[i] & 0x20;
                         } else if ((state->data_offset == 14 || state->data_offset == 15) && state->tmp) {
@@ -1067,14 +1074,13 @@ static cl_error_t scan_biff_for_xlm_macros_and_images(
                                 state->tmp = 0;
                             }
                         }
-#endif
                         break;
                     case BIFF_PARSER_BOUNDSHEET_RECORD:
                         if (state->data_offset == 4) {
                             state->tmp = buff[i];
                         } else if (state->data_offset == 5 && buff[i] == 1) { // Excel 4.0 macro sheet
                             cli_dbgmsg("[scan_biff_for_xlm_macros_and_images] Found XLM macro sheet\n");
-#if HAVE_JSON
+
                             if (SCAN_COLLECT_METADATA && (ctx->wrkproperty != NULL)) {
                                 cli_jsonbool(ctx->wrkproperty, "HasMacros", 1);
                                 json_object *macro_languages = cli_jsonarray(ctx->wrkproperty, "MacroLanguages");
@@ -1092,7 +1098,7 @@ static cl_error_t scan_biff_for_xlm_macros_and_images(
                                     }
                                 }
                             }
-#endif
+
                             *found_macro = true;
                         }
                         break;
@@ -1127,7 +1133,7 @@ static cl_error_t scan_biff_for_xlm_macros_and_images(
  * @brief Scan for XLM (Excel 4.0) macro sheets and images in an OLE2 Workbook stream.
  *
  * The stream should be encoded with <= BIFF8.
- * The found_macro and found_image out-params should be checked even if an error occured.
+ * The found_macro and found_image out-params should be checked even if an error occurred.
  *
  * @param hdr
  * @param prop
@@ -1157,9 +1163,9 @@ static cl_error_t scan_for_xlm_macros_and_images(ole2_header_t *hdr, property_t
     current_block = prop->start_block;
     len           = prop->size;
 
-    CLI_MALLOC(buff, 1 << hdr->log2_big_block_size,
-               cli_errmsg("OLE2 [scan_for_xlm_macros_and_images]: Unable to allocate memory for buff: %u\n", 1 << hdr->log2_big_block_size);
-               status = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(buff, 1 << hdr->log2_big_block_size,
+                                cli_errmsg("OLE2 [scan_for_xlm_macros_and_images]: Unable to allocate memory for buff: %u\n", 1 << hdr->log2_big_block_size);
+                                status = CL_EMEM);
 
     blk_bitset = cli_bitset_init();
     if (!blk_bitset) {
@@ -1207,7 +1213,7 @@ static cl_error_t scan_for_xlm_macros_and_images(ole2_header_t *hdr, property_t
     status = CL_SUCCESS;
 
 done:
-    FREE(buff);
+    CLI_FREE_AND_SET_NULL(buff);
 
     if (blk_bitset) {
         cli_bitset_free(blk_bitset);
@@ -1230,11 +1236,12 @@ static cl_error_t handler_enum(ole2_header_t *hdr, property_t *prop, const char
     char *name               = NULL;
     unsigned char *hwp_check = NULL;
     int32_t offset           = 0;
-#if HAVE_JSON
+
     json_object *arrobj  = NULL;
     json_object *strmobj = NULL;
 
     UNUSEDPARAM(handler_ctx);
+    UNUSEDPARAM(dir);
 
     name = cli_ole2_get_property_name2(prop->name, prop->name_size);
     if (name) {
@@ -1258,10 +1265,6 @@ static cl_error_t handler_enum(ole2_header_t *hdr, property_t *prop, const char
             }
         }
     }
-#else
-    UNUSEDPARAM(ctx);
-#endif
-    UNUSEDPARAM(dir);
 
     if (!hdr->has_vba) {
         if (!name)
@@ -1282,7 +1285,7 @@ static cl_error_t handler_enum(ole2_header_t *hdr, property_t *prop, const char
         }
         if (name) {
             if (!strcmp(name, "fileheader")) {
-                CLI_CALLOC(hwp_check, 1, 1 << hdr->log2_big_block_size, status = CL_EMEM);
+                CLI_MAX_CALLOC_OR_GOTO_DONE(hwp_check, 1, 1 << hdr->log2_big_block_size, status = CL_EMEM);
 
                 /* reading safety checks; do-while used for breaks */
                 do {
@@ -1313,10 +1316,10 @@ static cl_error_t handler_enum(ole2_header_t *hdr, property_t *prop, const char
                     /* compare against HWP signature; we could add the 15 padding NULLs too */
                     if (!memcmp(hwp_check + offset, "HWP Document File", 17)) {
                         hwp5_header_t *hwp_new;
-#if HAVE_JSON
+
                         cli_jsonstr(ctx->wrkproperty, "FileType", "CL_TYPE_HWP5");
-#endif
-                        CLI_CALLOC(hwp_new, 1, sizeof(hwp5_header_t), status = CL_EMEM);
+
+                        CLI_CALLOC_OR_GOTO_DONE(hwp_new, 1, sizeof(hwp5_header_t), status = CL_EMEM);
 
                         /*
                          * Copy the header information into our header struct.
@@ -1349,8 +1352,8 @@ static cl_error_t handler_enum(ole2_header_t *hdr, property_t *prop, const char
     status = CL_SUCCESS;
 
 done:
-    FREE(name);
-    FREE(hwp_check);
+    CLI_FREE_AND_SET_NULL(name);
+    CLI_FREE_AND_SET_NULL(hwp_check);
 
     return status;
 }
@@ -1567,7 +1570,7 @@ static cl_error_t handler_otf(ole2_header_t *hdr, property_t *prop, const char *
         cli_dbgmsg("OLE2 [handler_otf]: Dumping '%s' to '%s'\n", name, tempfile);
     }
 
-    CLI_MALLOC(buff, 1 << hdr->log2_big_block_size, ret = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(buff, 1 << hdr->log2_big_block_size, ret = CL_EMEM);
 
     blk_bitset = cli_bitset_init();
     if (!blk_bitset) {
@@ -1631,7 +1634,6 @@ static cl_error_t handler_otf(ole2_header_t *hdr, property_t *prop, const char *
         goto done;
     }
 
-#if HAVE_JSON
     /* JSON Output Summary Information */
     if (SCAN_COLLECT_METADATA && (ctx->properties != NULL)) {
         if (!name) {
@@ -1657,7 +1659,6 @@ static cl_error_t handler_otf(ole2_header_t *hdr, property_t *prop, const char *
             }
         }
     }
-#endif
 
     if (hdr->is_hwp) {
         if (!name) {
@@ -1677,11 +1678,11 @@ static cl_error_t handler_otf(ole2_header_t *hdr, property_t *prop, const char *
     ret = ret == CL_VIRUS ? CL_VIRUS : CL_SUCCESS;
 
 done:
-    FREE(name);
+    CLI_FREE_AND_SET_NULL(name);
     if (-1 != ofd) {
         close(ofd);
     }
-    FREE(buff);
+    CLI_FREE_AND_SET_NULL(buff);
     if (NULL != blk_bitset) {
         cli_bitset_free(blk_bitset);
     }
@@ -1726,7 +1727,7 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
     int nrounds           = 0;
     uint8_t *decryptDst   = NULL;
     encryption_key_t *key = (encryption_key_t *)handler_ctx;
-    uint64_t *rk          = NULL;
+    uint32_t *rk          = NULL;
     uint32_t bytesRead    = 0;
     uint64_t actualFileLength;
     uint64_t bytesWritten = 0;
@@ -1746,7 +1747,7 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
         goto done;
     }
 
-    CLI_MALLOC(rk, RKLENGTH(key->key_length_bits) * sizeof(uint64_t), ret = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(rk, RKLENGTH(key->key_length_bits) * sizeof(uint32_t), ret = CL_EMEM);
 
     print_ole2_property(prop);
 
@@ -1774,8 +1775,8 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
     }
 
     uint32_t blockSize = 1 << hdr->log2_big_block_size;
-    CLI_MALLOC(buff, blockSize + sizeof(uint64_t), ret = CL_EMEM);
-    CLI_MALLOC(decryptDst, blockSize, ret = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(buff, blockSize + sizeof(uint64_t), ret = CL_EMEM);
+    CLI_MAX_MALLOC_OR_GOTO_DONE(decryptDst, blockSize, ret = CL_EMEM);
 
     blk_bitset = cli_bitset_init();
     if (!blk_bitset) {
@@ -1873,8 +1874,6 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
         goto done;
     }
 
-#if HAVE_JSON
-
     /* JSON Output Summary Information */
     if (SCAN_COLLECT_METADATA && (ctx->properties != NULL)) {
         if (!name) {
@@ -1901,8 +1900,6 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
         }
     }
 
-#endif
-
     if (hdr->is_hwp) {
         if (!name) {
             name = cli_ole2_get_property_name2(prop->name, prop->name_size);
@@ -1921,11 +1918,11 @@ static cl_error_t handler_otf_encrypted(ole2_header_t *hdr, property_t *prop, co
     ret = ret == CL_VIRUS ? CL_VIRUS : CL_SUCCESS;
 
 done:
-    FREE(name);
+    CLI_FREE_AND_SET_NULL(name);
     if (-1 != ofd) {
         close(ofd);
     }
-    FREE(buff);
+    CLI_FREE_AND_SET_NULL(buff);
     if (NULL != blk_bitset) {
         cli_bitset_free(blk_bitset);
     }
@@ -1938,8 +1935,8 @@ done:
         free(tempfile);
         tempfile = NULL;
     }
-    FREE(decryptDst);
-    FREE(rk);
+    CLI_FREE_AND_SET_NULL(decryptDst);
+    CLI_FREE_AND_SET_NULL(rk);
 
     return ret;
 }
@@ -2136,14 +2133,14 @@ static cl_error_t generate_key_aes(const char *const password, encryption_key_t
     memcpy(key->key, doubleSha, tmp);
     ret = CL_SUCCESS;
 done:
-    FREE(buffer);
+    CLI_FREE_AND_SET_NULL(buffer);
 
     return ret;
 }
 
 static bool aes_128ecb_decrypt(const unsigned char *in, size_t length, unsigned char *out, const encryption_key_t *const key)
 {
-    uint64_t rk[RKLENGTH(128)];
+    uint32_t rk[RKLENGTH(128)];
     int nrounds;
     size_t i;
     bool bRet = false;
@@ -2578,11 +2575,9 @@ cl_error_t cli_ole2_extract(const char *dirname, cli_ctx *ctx, struct uniq **fil
 
         cli_dbgmsg("Encrypted with VelvetSweatshop: %d\n", bEncrypted);
 
-#if HAVE_JSON
         if (ctx->wrkproperty == ctx->properties) {
             cli_jsonint(ctx->wrkproperty, "EncryptedWithVelvetSweatshop", bEncrypted);
         }
-#endif /* HAVE_JSON */
     }
 
     /* 8 SBAT blocks per file block */
