@@ -1,7 +1,7 @@
 /*
  * OOXML JSON Internals
  *
- * Copyright (C) 2014-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *
  * Authors: Kevin Lin
  *
@@ -23,13 +23,9 @@
 #include "clamav-config.h"
 #endif
 
-#if HAVE_JSON
 #include "json.h"
-#endif
 
-#if HAVE_LIBXML2
 #include <libxml/xmlreader.h>
-#endif
 
 #include "clamav.h"
 #include "filetypes.h"
@@ -39,8 +35,6 @@
 #include "msxml_parser.h"
 #include "ooxml.h"
 
-#if HAVE_LIBXML2 && HAVE_JSON
-
 // clang-format off
 
 /*** OOXML MSDOC ***/
@@ -386,8 +380,6 @@ static cl_error_t ooxml_hwp_cb(int fd, const char *filepath, cli_ctx *ctx, const
     return ret;
 }
 
-#endif /* HAVE_LIBXML2 && HAVE_JSON */
-
 cli_file_t cli_ooxml_filetype(cli_ctx *ctx, fmap_t *map)
 {
     struct zip_requests requests;
@@ -428,7 +420,6 @@ cli_file_t cli_ooxml_filetype(cli_ctx *ctx, fmap_t *map)
 
 cl_error_t cli_process_ooxml(cli_ctx *ctx, int type)
 {
-#if HAVE_LIBXML2 && HAVE_JSON
     uint32_t loff  = 0;
     cl_error_t ret = CL_SUCCESS;
 
@@ -485,15 +476,4 @@ cl_error_t cli_process_ooxml(cli_ctx *ctx, int type)
     }
 
     return ret;
-#else
-    UNUSEDPARAM(ctx);
-    cli_dbgmsg("in cli_process_ooxml\n");
-#if !HAVE_LIBXML2
-    cli_dbgmsg("cli_process_ooxml: libxml2 needs to enabled!\n");
-#endif
-#if !HAVE_JSON
-    cli_dbgmsg("cli_process_ooxml: libjson needs to enabled!\n");
-#endif
-    return CL_SUCCESS;
-#endif
 }
