@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Tomasz Kojm, Trog
@@ -142,7 +142,7 @@ void cl_set_clcb_msg(clcb_msg callback)
     va_list args;                                         \
     size_t len = sizeof(x) - 1;                           \
     char buff[MSGBUFSIZ];                                 \
-    strncpy(buff, x, len);                                \
+    memcpy(buff, x, len);                                 \
     va_start(args, str);                                  \
     vsnprintf(buff + len, sizeof(buff) - len, str, args); \
     va_end(args)
@@ -216,13 +216,12 @@ int cli_matchregex(const char *str, const char *regex)
 
     return 0;
 }
-void *cli_malloc(size_t size)
+void *cli_max_malloc(size_t size)
 {
     void *alloc;
 
-    if (!size || size > CLI_MAX_ALLOCATION) {
-        cli_warnmsg("cli_malloc(): File or section is too large to scan (%zu bytes). \
-                     For your safety, ClamAV limits how much memory an operation can allocate to %zu bytes\n",
+    if (0 == size || size > CLI_MAX_ALLOCATION) {
+        cli_warnmsg("cli_max_malloc(): File or section is too large to scan (%zu bytes). For your safety, ClamAV limits how much memory an operation can allocate to %d bytes\n",
                     size, CLI_MAX_ALLOCATION);
         return NULL;
     }
@@ -231,19 +230,19 @@ void *cli_malloc(size_t size)
 
     if (!alloc) {
         perror("malloc_problem");
-        cli_errmsg("cli_malloc(): Can't allocate memory (%zu bytes).\n", size);
+        cli_errmsg("cli_max_malloc(): Can't allocate memory (%zu bytes).\n", size);
         return NULL;
-    } else
+    } else {
         return alloc;
+    }
 }
 
-void *cli_calloc(size_t nmemb, size_t size)
+void *cli_max_calloc(size_t nmemb, size_t size)
 {
     void *alloc;
 
-    if (!nmemb || !size || size > CLI_MAX_ALLOCATION || nmemb > CLI_MAX_ALLOCATION || (nmemb * size > CLI_MAX_ALLOCATION)) {
-        cli_warnmsg("cli_calloc2(): File or section is too large to scan (%zu bytes). \
-                     For your safety, ClamAV limits how much memory an operation can allocate to %zu bytes\n",
+    if (!nmemb || 0 == size || size > CLI_MAX_ALLOCATION || nmemb > CLI_MAX_ALLOCATION || (nmemb * size > CLI_MAX_ALLOCATION)) {
+        cli_warnmsg("cli_max_calloc(): File or section is too large to scan (%zu bytes). For your safety, ClamAV limits how much memory an operation can allocate to %d bytes\n",
                     size, CLI_MAX_ALLOCATION);
         return NULL;
     }
@@ -252,20 +251,19 @@ void *cli_calloc(size_t nmemb, size_t size)
 
     if (!alloc) {
         perror("calloc_problem");
-        cli_errmsg("cli_calloc(): Can't allocate memory (%zu bytes).\n", (nmemb * size));
+        cli_errmsg("cli_max_calloc(): Can't allocate memory (%lu bytes).\n", (unsigned long int)(nmemb * size));
         return NULL;
-    } else
+    } else {
         return alloc;
+    }
 }
 
-void *cli_realloc(void *ptr, size_t size)
+void *cli_safer_realloc(void *ptr, size_t size)
 {
     void *alloc;
 
-    if (!size || size > CLI_MAX_ALLOCATION) {
-        cli_warnmsg("cli_realloc(): File or section is too large to scan (%zu bytes). \
-                     For your safety, ClamAV limits how much memory an operation can allocate to %zu bytes\n",
-                    size, CLI_MAX_ALLOCATION);
+    if (0 == size) {
+        cli_errmsg("cli_max_realloc(): Attempt to allocate 0 bytes. Please report to https://github.com/Cisco-Talos/clamav/issues\n");
         return NULL;
     }
 
@@ -273,20 +271,19 @@ void *cli_realloc(void *ptr, size_t size)
 
     if (!alloc) {
         perror("realloc_problem");
-        cli_errmsg("cli_realloc(): Can't re-allocate memory to %zu bytes.\n", size);
+        cli_errmsg("cli_max_realloc(): Can't re-allocate memory to %lu bytes.\n", (unsigned long int)size);
         return NULL;
-    } else
+    } else {
         return alloc;
+    }
 }
 
-void *cli_realloc2(void *ptr, size_t size)
+void *cli_safer_realloc_or_free(void *ptr, size_t size)
 {
     void *alloc;
 
-    if (!size || size > CLI_MAX_ALLOCATION) {
-        cli_warnmsg("cli_realloc2(): File or section is too large to scan (%zu bytes). \
-                     For your safety, ClamAV limits how much memory an operation can allocate to %zu bytes\n",
-                    size, CLI_MAX_ALLOCATION);
+    if (0 == size) {
+        cli_errmsg("cli_max_realloc_or_free(): Attempt to allocate 0 bytes. Please report to https://github.com/Cisco-Talos/clamav/issues\n");
         return NULL;
     }
 
@@ -294,20 +291,73 @@ void *cli_realloc2(void *ptr, size_t size)
 
     if (!alloc) {
         perror("realloc_problem");
-        cli_errmsg("cli_realloc2(): Can't re-allocate memory to %zu bytes.\n", size);
-        if (ptr)
+        cli_errmsg("cli_max_realloc_or_free(): Can't re-allocate memory to %lu bytes.\n", (unsigned long int)size);
+
+        // free the original pointer
+        if (ptr) {
             free(ptr);
+        }
+
         return NULL;
-    } else
+    } else {
         return alloc;
+    }
 }
 
-char *cli_strdup(const char *s)
+void *cli_max_realloc(void *ptr, size_t size)
+{
+    void *alloc;
+
+    if (0 == size || size > CLI_MAX_ALLOCATION) {
+        cli_warnmsg("cli_max_realloc(): File or section is too large to scan (%zu bytes). For your safety, ClamAV limits how much memory an operation can allocate to %d bytes\n",
+                    size, CLI_MAX_ALLOCATION);
+        return NULL;
+    }
+
+    alloc = realloc(ptr, size);
+
+    if (!alloc) {
+        perror("realloc_problem");
+        cli_errmsg("cli_max_realloc(): Can't re-allocate memory to %zu bytes.\n", size);
+        return NULL;
+    } else {
+        return alloc;
+    }
+}
+
+void *cli_max_realloc_or_free(void *ptr, size_t size)
+{
+    void *alloc;
+
+    if (0 == size || size > CLI_MAX_ALLOCATION) {
+        cli_warnmsg("cli_max_realloc_or_free(): File or section is too large to scan (%zu bytes). For your safety, ClamAV limits how much memory an operation can allocate to %d bytes\n",
+                    size, CLI_MAX_ALLOCATION);
+        return NULL;
+    }
+
+    alloc = realloc(ptr, size);
+
+    if (!alloc) {
+        perror("realloc_problem");
+        cli_errmsg("cli_max_realloc_or_free(): Can't re-allocate memory to %zu bytes.\n", size);
+
+        // free the original pointer
+        if (ptr) {
+            free(ptr);
+        }
+
+        return NULL;
+    } else {
+        return alloc;
+    }
+}
+
+char *cli_safer_strdup(const char *s)
 {
     char *alloc;
 
     if (s == NULL) {
-        cli_errmsg("cli_strdup(): passed reference is NULL, nothing to duplicate\n");
+        cli_errmsg("cli_safer_strdup(): passed reference is NULL, nothing to duplicate\n");
         return NULL;
     }
 
@@ -315,7 +365,7 @@ char *cli_strdup(const char *s)
 
     if (!alloc) {
         perror("strdup_problem");
-        cli_errmsg("cli_strdup(): Can't allocate memory (%u bytes).\n", (unsigned int)strlen(s));
+        cli_errmsg("cli_safer_strdup(): Can't allocate memory (%u bytes).\n", (unsigned int)strlen(s));
         return NULL;
     }
 
@@ -476,7 +526,7 @@ int cli_filecopy(const char *src, const char *dest)
         return -1;
     }
 
-    if (!(buffer = cli_malloc(FILEBUFF))) {
+    if (!(buffer = malloc(FILEBUFF))) {
         close(s);
         close(d);
         return -1;
@@ -637,7 +687,7 @@ static cl_error_t handle_filetype(const char *fname, int flags,
 
     if (*stated == -1) {
         /* we failed a stat() or lstat() */
-        char *fname_copy = cli_strdup(fname);
+        char *fname_copy = cli_safer_strdup(fname);
         if (NULL == fname_copy) {
             goto done;
         }
@@ -649,7 +699,7 @@ static cl_error_t handle_filetype(const char *fname, int flags,
         *ft = ft_unknown;
     } else if (*ft == ft_skipped_link || *ft == ft_skipped_special) {
         /* skipped filetype */
-        char *fname_copy = cli_strdup(fname);
+        char *fname_copy = cli_safer_strdup(fname);
         if (NULL == fname_copy) {
             goto done;
         }
@@ -727,7 +777,7 @@ cl_error_t cli_ftw(char *path, int flags, int maxdepth, cli_ftw_cb callback, str
      */
     if (entry.is_dir) {
         /* Allocate the filename for the callback function. TODO: this FTW code is spaghetti, refactor. */
-        filename_for_callback = cli_strdup(path);
+        filename_for_callback = cli_safer_strdup(path);
         if (NULL == filename_for_callback) {
             goto done;
         }
@@ -750,7 +800,7 @@ cl_error_t cli_ftw(char *path, int flags, int maxdepth, cli_ftw_cb callback, str
         entry.dirname = path;
     } else {
         /* Allocate the filename for the callback function within the handle_entry function. TODO: this FTW code is spaghetti, refactor. */
-        filename_for_handleentry = cli_strdup(path);
+        filename_for_handleentry = cli_safer_strdup(path);
         if (NULL == filename_for_handleentry) {
             goto done;
         }
@@ -826,7 +876,7 @@ static cl_error_t cli_ftw_dir(const char *dirname, int flags, int maxdepth, cli_
 #else
             ft = ft_unknown;
 #endif
-            fname = (char *)cli_malloc(strlen(dirname) + strlen(dent->d_name) + 2);
+            fname = (char *)cli_max_malloc(strlen(dirname) + strlen(dent->d_name) + 2);
             if (!fname) {
                 ret = callback(NULL, NULL, dirname, error_mem, data);
                 if (ret != CL_SUCCESS)
@@ -856,7 +906,7 @@ static cl_error_t cli_ftw_dir(const char *dirname, int flags, int maxdepth, cli_
             }
 
             if (stated && (flags & CLI_FTW_NEED_STAT)) {
-                statbufp = cli_malloc(sizeof(*statbufp));
+                statbufp = malloc(sizeof(*statbufp));
                 if (!statbufp) {
                     ret = callback(stated ? &statbuf : NULL, NULL, fname, error_mem, data);
                     free(fname);
@@ -873,7 +923,7 @@ static cl_error_t cli_ftw_dir(const char *dirname, int flags, int maxdepth, cli_
             }
 
             entries_cnt++;
-            entries = cli_realloc(entries, entries_cnt * sizeof(*entries));
+            entries = cli_max_realloc(entries, entries_cnt * sizeof(*entries));
             if (!entries) {
                 ret = callback(stated ? &statbuf : NULL, NULL, fname, error_mem, data);
                 free(fname);
@@ -930,7 +980,7 @@ static cl_error_t cli_ftw_dir(const char *dirname, int flags, int maxdepth, cli_
  * used */
 const char *cli_strerror(int errnum, char *buf, size_t len)
 {
-    char *err;
+    const char *err;
 #ifdef CL_THREAD_SAFE
     pthread_mutex_lock(&cli_strerror_mutex);
 #endif
@@ -954,7 +1004,7 @@ static char *cli_md5buff(const unsigned char *buffer, unsigned int len, unsigned
     if (dig)
         memcpy(dig, digest, 16);
 
-    if (!(md5str = (char *)cli_calloc(32 + 1, sizeof(char))))
+    if (!(md5str = (char *)cli_max_calloc(32 + 1, sizeof(char))))
         return NULL;
 
     pt = md5str;
@@ -993,7 +1043,7 @@ char *cli_sanitize_filepath(const char *filepath, size_t filepath_len, char **sa
         *sanitized_filebase = NULL;
     }
 
-    sanitized_filepath = cli_calloc(filepath_len + 1, sizeof(unsigned char));
+    sanitized_filepath = cli_max_calloc(filepath_len + 1, sizeof(unsigned char));
     if (NULL == sanitized_filepath) {
         cli_dbgmsg("cli_sanitize_filepath: out of memory\n");
         goto done;
@@ -1146,7 +1196,7 @@ char *cli_genfname(const char *prefix)
         len = strlen("clamav-") + 48 + strlen(".tmp") + 1; /* clamav-{48}.tmp\0 */
     }
 
-    fname = (char *)cli_calloc(len, sizeof(char));
+    fname = (char *)cli_max_calloc(len, sizeof(char));
     if (!fname) {
         cli_dbgmsg("cli_genfname: no memory left for fname\n");
         if (NULL != sanitized_prefix) {
@@ -1207,7 +1257,7 @@ char *cli_newfilepath(const char *dir, const char *fname)
     }
 
     len      = strlen(mdir) + strlen(PATHSEP) + strlen(fname) + 1; /* mdir/fname\0 */
-    fullpath = (char *)cli_calloc(len, sizeof(char));
+    fullpath = (char *)cli_max_calloc(len, sizeof(char));
     if (NULL == fullpath) {
         cli_dbgmsg("cli_newfilepath('%s'): out of memory\n", mdir);
         return NULL;
@@ -1262,7 +1312,7 @@ char *cli_gentemp_with_prefix(const char *dir, const char *prefix)
     }
 
     len      = strlen(mdir) + strlen(PATHSEP) + strlen(fname) + 1; /* mdir/fname\0 */
-    fullpath = (char *)cli_calloc(len, sizeof(char));
+    fullpath = (char *)cli_max_calloc(len, sizeof(char));
     if (!fullpath) {
         free(fname);
         cli_dbgmsg("cli_gentemp_with_prefix('%s'): out of memory\n", mdir);
