@@ -1,7 +1,7 @@
 /*
  *  Detect phishing, based on URL spoofing detection.
  *
- *  Copyright (C) 2013-2022 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Török Edvin
@@ -92,7 +92,7 @@ The _domain_list_ is a list of pairs of realLink, displayedLink (any of which ca
 This is the list of domains we do phishing detection for (such as ebay,paypal,chase,....)
 We can't decide to stop processing here or not, so we just set a flag.
 
-Note(*!*): the flags are modified by the the domain list checker. If domain is found, then the flags associated with it filter the default compile-time flags.
+Note(*!*): the flags are modified by the domain list checker. If domain is found, then the flags associated with it filter the default compile-time flags.
 
 5. _Hostname_ is extracted from the _displayed URL_.
 It is checked against the _allow_list_, and _domain_list_.
@@ -211,6 +211,7 @@ static void url_check_init(struct url_check* urls)
     string_init_c(&urls->realLink, NULL);
     string_init_c(&urls->displayLink, NULL);
     string_init_c(&urls->pre_fixup.pre_displayLink, NULL);
+    urls->flags = 0;
 }
 
 /* string reference counting implementation,
@@ -259,12 +260,12 @@ static void string_init_c(struct string* dest, char* data)
 static int string_assign_concatenated(struct string* dest, const char* prefix, const char* begin, const char* end)
 {
     const size_t prefix_len = strlen(prefix);
-    char* ret               = cli_malloc(prefix_len + end - begin + 1);
+    char* ret               = cli_max_malloc(prefix_len + end - begin + 1);
     if (!ret) {
         cli_errmsg("Phishcheck: Unable to allocate memory for string_assign_concatenated\n");
         return CL_EMEM;
     }
-    strncpy(ret, prefix, prefix_len);
+    strncpy(ret, prefix, prefix_len + end - begin + 1);
     strncpy(ret + prefix_len, begin, end - begin);
     ret[prefix_len + end - begin] = '\0';
     string_free(dest);
@@ -275,7 +276,7 @@ static int string_assign_concatenated(struct string* dest, const char* prefix, c
 /* make a copy of the string between start -> end*/
 static int string_assign_dup(struct string* dest, const char* start, const char* end)
 {
-    char* ret = cli_malloc(end - start + 1);
+    char* ret = cli_max_malloc(end - start + 1);
     if (!ret) {
         cli_errmsg("Phishcheck: Unable to allocate memory for string_assign_dup\n");
         return CL_EMEM;
@@ -323,7 +324,7 @@ static int build_regex(regex_t* preg, const char* regex, int nosub)
     if (rc) {
 
         size_t buflen = cli_regerror(rc, preg, NULL, 0);
-        char* errbuf  = cli_malloc(buflen);
+        char* errbuf  = malloc(buflen);
 
         if (errbuf) {
             cli_regerror(rc, preg, errbuf, buflen);
@@ -1480,7 +1481,7 @@ static enum phish_status phishingCheck(cli_ctx* ctx, struct url_check* urls)
                                                urls->realLink.data,
                                                strlen(urls->realLink.data),
                                                &phishing_verdict))) {
-        cli_dbgmsg("Error occured in url_hash_match\n");
+        cli_dbgmsg("Error occurred in url_hash_match\n");
         goto done;
     } else if (phishing_verdict != CL_PHISH_NODECISION) {
         if (phishing_verdict == CL_PHISH_CLEAN) {
@@ -1534,15 +1535,15 @@ static enum phish_status phishingCheck(cli_ctx* ctx, struct url_check* urls)
      * Eg:
      *      R:.+\.malicious\.net([/?].*)?:.+\.benign\.com
      */
-    /* Provide copies of the oirinal URL's, because domain_list_match() may modify the buffer,
+    /* Provide copies of the original URL's, because domain_list_match() may modify the buffer,
        and we don't want that to happen in this case. */
-    realData = cli_strdup(urls->realLink.data);
+    realData = cli_safer_strdup(urls->realLink.data);
     if (!realData) {
         cli_errmsg("Phishcheck: Failed to allocate memory for temporary real link string.\n");
         phishing_verdict = CL_PHISH_CLEAN;
         goto done;
     }
-    displayData = cli_strdup(urls->displayLink.data);
+    displayData = cli_safer_strdup(urls->displayLink.data);
     if (!displayData) {
         cli_errmsg("Phishcheck: Failed to allocate memory for temporary display link string.\n");
         phishing_verdict = CL_PHISH_CLEAN;
