@@ -1,7 +1,7 @@
 /*
  *  Extract component parts of ARJ archives
  *
- *  Copyright (C) 2013-2021 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
+ *  Copyright (C) 2013-2024 Cisco Systems, Inc. and/or its affiliates. All rights reserved.
  *  Copyright (C) 2007-2013 Sourcefire, Inc.
  *
  *  Authors: Nigel Horne
@@ -36,7 +36,7 @@ typedef struct arj_metadata_tag {
     size_t offset;
 } arj_metadata_t;
 
-cl_error_t cli_unarj_open(fmap_t *map, const char *dirname, arj_metadata_t *metadata, size_t off);
+cl_error_t cli_unarj_open(fmap_t *map, const char *dirname, arj_metadata_t *metadata);
 cl_error_t cli_unarj_prepare_file(const char *dirname, arj_metadata_t *metadata);
 cl_error_t cli_unarj_extract_file(const char *dirname, arj_metadata_t *metadata);
 
